# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .compute import (
    AbandonInstancesInstanceGroupManagerRequest,
    AbandonInstancesRegionInstanceGroupManagerRequest,
    AcceleratorConfig,
    Accelerators,
    AcceleratorType,
    AcceleratorTypeAggregatedList,
    AcceleratorTypeList,
    AcceleratorTypesScopedList,
    AccessConfig,
    AddAccessConfigInstanceRequest,
    AddAssociationFirewallPolicyRequest,
    AddAssociationNetworkFirewallPolicyRequest,
    AddAssociationOrganizationSecurityPolicyRequest,
    AddAssociationRegionNetworkFirewallPolicyRequest,
    AddHealthCheckTargetPoolRequest,
    AddInstancesInstanceGroupRequest,
    AddInstanceTargetPoolRequest,
    AddNetworkInterfaceInstanceRequest,
    AddNodesNodeGroupRequest,
    AddPacketMirroringRuleFirewallPolicyRequest,
    AddPacketMirroringRuleNetworkFirewallPolicyRequest,
    AddPeeringNetworkRequest,
    AddResourcePoliciesDiskRequest,
    AddResourcePoliciesInstanceRequest,
    AddResourcePoliciesRegionDiskRequest,
    Address,
    AddressAggregatedList,
    AddressesScopedList,
    AddressList,
    AddRuleFirewallPolicyRequest,
    AddRuleNetworkFirewallPolicyRequest,
    AddRuleOrganizationSecurityPolicyRequest,
    AddRuleRegionNetworkFirewallPolicyRequest,
    AddRuleRegionSecurityPolicyRequest,
    AddRuleSecurityPolicyRequest,
    AddSignedUrlKeyBackendBucketRequest,
    AddSignedUrlKeyBackendServiceRequest,
    AdvancedMachineFeatures,
    AggregatedListAcceleratorTypesRequest,
    AggregatedListAddressesRequest,
    AggregatedListAutoscalersRequest,
    AggregatedListBackendServicesRequest,
    AggregatedListDisksRequest,
    AggregatedListDiskTypesRequest,
    AggregatedListForwardingRulesRequest,
    AggregatedListFutureReservationsRequest,
    AggregatedListGlobalOperationsRequest,
    AggregatedListHealthChecksRequest,
    AggregatedListInstanceGroupManagersRequest,
    AggregatedListInstanceGroupsRequest,
    AggregatedListInstancesRequest,
    AggregatedListInstanceTemplatesRequest,
    AggregatedListInstantSnapshotsRequest,
    AggregatedListInterconnectAttachmentsRequest,
    AggregatedListMachineTypesRequest,
    AggregatedListNetworkAttachmentsRequest,
    AggregatedListNetworkEdgeSecurityServicesRequest,
    AggregatedListNetworkEndpointGroupsRequest,
    AggregatedListNetworkFirewallPoliciesRequest,
    AggregatedListNodeGroupsRequest,
    AggregatedListNodeTemplatesRequest,
    AggregatedListNodeTypesRequest,
    AggregatedListPacketMirroringsRequest,
    AggregatedListPublicDelegatedPrefixesRequest,
    AggregatedListRegionCommitmentsRequest,
    AggregatedListReservationsRequest,
    AggregatedListResourcePoliciesRequest,
    AggregatedListRoutersRequest,
    AggregatedListSecurityPoliciesRequest,
    AggregatedListServiceAttachmentsRequest,
    AggregatedListSnapshotsRequest,
    AggregatedListSslCertificatesRequest,
    AggregatedListSslPoliciesRequest,
    AggregatedListStoragePoolsRequest,
    AggregatedListStoragePoolTypesRequest,
    AggregatedListSubnetworksRequest,
    AggregatedListTargetHttpProxiesRequest,
    AggregatedListTargetHttpsProxiesRequest,
    AggregatedListTargetInstancesRequest,
    AggregatedListTargetPoolsRequest,
    AggregatedListTargetTcpProxiesRequest,
    AggregatedListTargetVpnGatewaysRequest,
    AggregatedListUrlMapsRequest,
    AggregatedListVpnGatewaysRequest,
    AggregatedListVpnTunnelsRequest,
    AliasIpRange,
    AllocationAggregateReservation,
    AllocationAggregateReservationReservedResourceInfo,
    AllocationAggregateReservationReservedResourceInfoAccelerator,
    AllocationReservationSharingPolicy,
    AllocationResourceStatus,
    AllocationResourceStatusSpecificSKUAllocation,
    AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk,
    AllocationSpecificSKUAllocationReservedInstanceProperties,
    AllocationSpecificSKUReservation,
    Allowed,
    AnnouncePublicAdvertisedPrefixeRequest,
    AnnouncePublicDelegatedPrefixeRequest,
    ApplyUpdatesToInstancesInstanceGroupManagerRequest,
    ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest,
    AttachDiskInstanceRequest,
    AttachedDisk,
    AttachedDiskInitializeParams,
    AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
    AttachNetworkEndpointsNetworkEndpointGroupRequest,
    AttachNetworkEndpointsRegionNetworkEndpointGroupRequest,
    AuditConfig,
    AuditLogConfig,
    Autoscaler,
    AutoscalerAggregatedList,
    AutoscalerList,
    AutoscalersScopedList,
    AutoscalerStatusDetails,
    AutoscalingPolicy,
    AutoscalingPolicyCpuUtilization,
    AutoscalingPolicyCustomMetricUtilization,
    AutoscalingPolicyLoadBalancingUtilization,
    AutoscalingPolicyScaleDownControl,
    AutoscalingPolicyScaleInControl,
    AutoscalingPolicyScalingSchedule,
    AWSV4Signature,
    Backend,
    BackendBucket,
    BackendBucketCdnPolicy,
    BackendBucketCdnPolicyBypassCacheOnRequestHeader,
    BackendBucketCdnPolicyCacheKeyPolicy,
    BackendBucketCdnPolicyNegativeCachingPolicy,
    BackendBucketList,
    BackendBucketListUsable,
    BackendBucketUsedBy,
    BackendCustomMetric,
    BackendService,
    BackendServiceAggregatedList,
    BackendServiceCdnPolicy,
    BackendServiceCdnPolicyBypassCacheOnRequestHeader,
    BackendServiceCdnPolicyNegativeCachingPolicy,
    BackendServiceConnectionTrackingPolicy,
    BackendServiceCustomMetric,
    BackendServiceDynamicForwarding,
    BackendServiceDynamicForwardingIpPortSelection,
    BackendServiceFailoverPolicy,
    BackendServiceGroupHealth,
    BackendServiceHAPolicy,
    BackendServiceHAPolicyLeader,
    BackendServiceHAPolicyLeaderNetworkEndpoint,
    BackendServiceHttpCookie,
    BackendServiceIAP,
    BackendServiceList,
    BackendServiceListUsable,
    BackendServiceLocalityLoadBalancingPolicyConfig,
    BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy,
    BackendServiceLocalityLoadBalancingPolicyConfigPolicy,
    BackendServiceLogConfig,
    BackendServiceNetworkPassThroughLbTrafficPolicy,
    BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity,
    BackendServiceReference,
    BackendServicesGetEffectiveSecurityPoliciesResponse,
    BackendServicesScopedList,
    BackendServiceTlsSettings,
    BackendServiceTlsSettingsSubjectAltName,
    BackendServiceUsedBy,
    BfdPacket,
    BfdStatus,
    BfdStatusPacketCounts,
    BgpRoute,
    BgpRouteAsPath,
    BgpRouteNetworkLayerReachabilityInformation,
    Binding,
    BulkInsertDiskRequest,
    BulkInsertDiskResource,
    BulkInsertInstanceRequest,
    BulkInsertInstanceResource,
    BulkInsertInstanceResourcePerInstanceProperties,
    BulkInsertOperationStatus,
    BulkInsertRegionDiskRequest,
    BulkInsertRegionInstanceRequest,
    BulkSetLabelsDiskRequest,
    BulkSetLabelsRequest,
    BulkZoneSetLabelsRequest,
    BundledLocalSsds,
    CacheInvalidationRule,
    CacheKeyPolicy,
    CalendarModeAdviceRequest,
    CalendarModeAdviceResponse,
    CalendarModeAdviceRpcRequest,
    CalendarModeRecommendation,
    CancelFutureReservationRequest,
    CancelInstanceGroupManagerResizeRequestRequest,
    CancelRegionInstanceGroupManagerResizeRequestRequest,
    CircuitBreakers,
    CloneRulesFirewallPolicyRequest,
    CloneRulesNetworkFirewallPolicyRequest,
    CloneRulesRegionNetworkFirewallPolicyRequest,
    Commitment,
    CommitmentAggregatedList,
    CommitmentList,
    CommitmentResourceStatus,
    CommitmentsScopedList,
    ConfidentialInstanceConfig,
    ConnectionDraining,
    ConsistentHashLoadBalancerSettings,
    ConsistentHashLoadBalancerSettingsHttpCookie,
    CopyRulesOrganizationSecurityPolicyRequest,
    CorsPolicy,
    CreateInstancesInstanceGroupManagerRequest,
    CreateInstancesRegionInstanceGroupManagerRequest,
    CreateMembersInterconnectGroupRequest,
    CreateSnapshotDiskRequest,
    CreateSnapshotRegionDiskRequest,
    CrossSiteNetwork,
    CrossSiteNetworkList,
    CustomerEncryptionKey,
    CustomerEncryptionKeyProtectedDisk,
    CustomErrorResponsePolicy,
    CustomErrorResponsePolicyCustomErrorResponseRule,
    Data,
    Date,
    DeleteAccessConfigInstanceRequest,
    DeleteAddressRequest,
    DeleteAutoscalerRequest,
    DeleteBackendBucketRequest,
    DeleteBackendServiceRequest,
    DeleteCrossSiteNetworkRequest,
    DeleteDiskRequest,
    DeleteExternalVpnGatewayRequest,
    DeleteFirewallPolicyRequest,
    DeleteFirewallRequest,
    DeleteForwardingRuleRequest,
    DeleteFutureReservationRequest,
    DeleteGlobalAddressRequest,
    DeleteGlobalForwardingRuleRequest,
    DeleteGlobalNetworkEndpointGroupRequest,
    DeleteGlobalOperationRequest,
    DeleteGlobalOperationResponse,
    DeleteGlobalOrganizationOperationRequest,
    DeleteGlobalOrganizationOperationResponse,
    DeleteGlobalPublicDelegatedPrefixeRequest,
    DeleteHealthCheckRequest,
    DeleteImageRequest,
    DeleteInstanceGroupManagerRequest,
    DeleteInstanceGroupManagerResizeRequestRequest,
    DeleteInstanceGroupRequest,
    DeleteInstanceRequest,
    DeleteInstancesInstanceGroupManagerRequest,
    DeleteInstancesRegionInstanceGroupManagerRequest,
    DeleteInstanceTemplateRequest,
    DeleteInstantSnapshotRequest,
    DeleteInterconnectAttachmentGroupRequest,
    DeleteInterconnectAttachmentRequest,
    DeleteInterconnectGroupRequest,
    DeleteInterconnectRequest,
    DeleteLicenseRequest,
    DeleteMachineImageRequest,
    DeleteNetworkAttachmentRequest,
    DeleteNetworkEdgeSecurityServiceRequest,
    DeleteNetworkEndpointGroupRequest,
    DeleteNetworkFirewallPolicyRequest,
    DeleteNetworkInterfaceInstanceRequest,
    DeleteNetworkRequest,
    DeleteNodeGroupRequest,
    DeleteNodesNodeGroupRequest,
    DeleteNodeTemplateRequest,
    DeleteOrganizationSecurityPolicyRequest,
    DeletePacketMirroringRequest,
    DeletePerInstanceConfigsInstanceGroupManagerRequest,
    DeletePerInstanceConfigsRegionInstanceGroupManagerRequest,
    DeletePublicAdvertisedPrefixeRequest,
    DeletePublicDelegatedPrefixeRequest,
    DeleteRegionAutoscalerRequest,
    DeleteRegionBackendServiceRequest,
    DeleteRegionDiskRequest,
    DeleteRegionHealthCheckRequest,
    DeleteRegionHealthCheckServiceRequest,
    DeleteRegionInstanceGroupManagerRequest,
    DeleteRegionInstanceGroupManagerResizeRequestRequest,
    DeleteRegionInstanceTemplateRequest,
    DeleteRegionInstantSnapshotRequest,
    DeleteRegionMultiMigRequest,
    DeleteRegionNetworkEndpointGroupRequest,
    DeleteRegionNetworkFirewallPolicyRequest,
    DeleteRegionNotificationEndpointRequest,
    DeleteRegionOperationRequest,
    DeleteRegionOperationResponse,
    DeleteRegionSecurityPolicyRequest,
    DeleteRegionSnapshotRequest,
    DeleteRegionSslCertificateRequest,
    DeleteRegionSslPolicyRequest,
    DeleteRegionTargetHttpProxyRequest,
    DeleteRegionTargetHttpsProxyRequest,
    DeleteRegionTargetTcpProxyRequest,
    DeleteRegionUrlMapRequest,
    DeleteReservationRequest,
    DeleteResourcePolicyRequest,
    DeleteRoutePolicyRouterRequest,
    DeleteRouteRequest,
    DeleteRouterRequest,
    DeleteSecurityPolicyRequest,
    DeleteServiceAttachmentRequest,
    DeleteSignedUrlKeyBackendBucketRequest,
    DeleteSignedUrlKeyBackendServiceRequest,
    DeleteSnapshotRequest,
    DeleteSslCertificateRequest,
    DeleteSslPolicyRequest,
    DeleteStoragePoolRequest,
    DeleteSubnetworkRequest,
    DeleteTargetGrpcProxyRequest,
    DeleteTargetHttpProxyRequest,
    DeleteTargetHttpsProxyRequest,
    DeleteTargetInstanceRequest,
    DeleteTargetPoolRequest,
    DeleteTargetSslProxyRequest,
    DeleteTargetTcpProxyRequest,
    DeleteTargetVpnGatewayRequest,
    DeleteUrlMapRequest,
    DeleteVpnGatewayRequest,
    DeleteVpnTunnelRequest,
    DeleteWireGroupRequest,
    DeleteZoneOperationRequest,
    DeleteZoneOperationResponse,
    Denied,
    DeprecateImageRequest,
    DeprecationStatus,
    DetachDiskInstanceRequest,
    DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
    DetachNetworkEndpointsNetworkEndpointGroupRequest,
    DetachNetworkEndpointsRegionNetworkEndpointGroupRequest,
    DisableXpnHostProjectRequest,
    DisableXpnResourceProjectRequest,
    Disk,
    DiskAggregatedList,
    DiskAsyncReplication,
    DiskAsyncReplicationList,
    DiskInstantiationConfig,
    DiskList,
    DiskMoveRequest,
    DiskParams,
    DiskResourceStatus,
    DiskResourceStatusAsyncReplicationStatus,
    DisksAddResourcePoliciesRequest,
    DiskSettings,
    DiskSettingsAccessLocation,
    DiskSettingsAccessLocationAccessLocationPreference,
    DisksRemoveResourcePoliciesRequest,
    DisksResizeRequest,
    DisksScopedList,
    DisksStartAsyncReplicationRequest,
    DisksStopGroupAsyncReplicationResource,
    DiskType,
    DiskTypeAggregatedList,
    DiskTypeList,
    DiskTypesScopedList,
    DisplayDevice,
    DistributionPolicy,
    DistributionPolicyZoneConfiguration,
    Duration,
    EnableXpnHostProjectRequest,
    EnableXpnResourceProjectRequest,
    Error,
    ErrorDetails,
    ErrorInfo,
    Errors,
    ExchangedPeeringRoute,
    ExchangedPeeringRoutesList,
    ExpandIpCidrRangeSubnetworkRequest,
    Expr,
    ExternalVpnGateway,
    ExternalVpnGatewayInterface,
    ExternalVpnGatewayList,
    FileContentBuffer,
    Firewall,
    FirewallList,
    FirewallLogConfig,
    FirewallParams,
    FirewallPoliciesListAssociationsResponse,
    FirewallPoliciesScopedList,
    FirewallPolicy,
    FirewallPolicyAssociation,
    FirewallPolicyList,
    FirewallPolicyRule,
    FirewallPolicyRuleMatcher,
    FirewallPolicyRuleMatcherLayer4Config,
    FirewallPolicyRuleSecureTag,
    FixedOrPercent,
    FlexibleTimeRange,
    ForwardingRule,
    ForwardingRuleAggregatedList,
    ForwardingRuleList,
    ForwardingRuleReference,
    ForwardingRuleServiceDirectoryRegistration,
    ForwardingRulesScopedList,
    FutureReservation,
    FutureReservationCommitmentInfo,
    FutureReservationsAggregatedListResponse,
    FutureReservationsListResponse,
    FutureReservationSpecificSKUProperties,
    FutureReservationsScopedList,
    FutureReservationStatus,
    FutureReservationStatusExistingMatchingUsageInfo,
    FutureReservationStatusLastKnownGoodState,
    FutureReservationStatusLastKnownGoodStateFutureReservationSpecs,
    FutureReservationStatusSpecificSKUProperties,
    FutureReservationTimeWindow,
    FutureResourcesRecommendation,
    FutureResourcesRecommendationOtherLocation,
    FutureResourcesSpec,
    FutureResourcesSpecAggregateResources,
    FutureResourcesSpecLocalSsdPartition,
    FutureResourcesSpecLocationPolicy,
    FutureResourcesSpecLocationPolicyLocation,
    FutureResourcesSpecSpecificSKUResources,
    FutureResourcesSpecTargetResources,
    GetAcceleratorTypeRequest,
    GetAddressRequest,
    GetAssociationFirewallPolicyRequest,
    GetAssociationNetworkFirewallPolicyRequest,
    GetAssociationOrganizationSecurityPolicyRequest,
    GetAssociationRegionNetworkFirewallPolicyRequest,
    GetAutoscalerRequest,
    GetBackendBucketRequest,
    GetBackendServiceRequest,
    GetCrossSiteNetworkRequest,
    GetDiagnosticsInterconnectRequest,
    GetDiskRequest,
    GetDiskSettingRequest,
    GetDiskTypeRequest,
    GetEffectiveFirewallsInstanceRequest,
    GetEffectiveFirewallsNetworkRequest,
    GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest,
    GetEffectiveSecurityPoliciesBackendServiceRequest,
    GetExternalVpnGatewayRequest,
    GetFirewallPolicyRequest,
    GetFirewallRequest,
    GetForwardingRuleRequest,
    GetFromFamilyImageRequest,
    GetFutureReservationRequest,
    GetGlobalAddressRequest,
    GetGlobalForwardingRuleRequest,
    GetGlobalNetworkEndpointGroupRequest,
    GetGlobalOperationRequest,
    GetGlobalOrganizationOperationRequest,
    GetGlobalPublicDelegatedPrefixeRequest,
    GetGuestAttributesInstanceRequest,
    GetHealthBackendServiceRequest,
    GetHealthCheckRequest,
    GetHealthRegionBackendServiceRequest,
    GetHealthTargetPoolRequest,
    GetIamPolicyBackendBucketRequest,
    GetIamPolicyBackendServiceRequest,
    GetIamPolicyDiskRequest,
    GetIamPolicyFirewallPolicyRequest,
    GetIamPolicyImageRequest,
    GetIamPolicyInstanceRequest,
    GetIamPolicyInstanceTemplateRequest,
    GetIamPolicyInstantSnapshotRequest,
    GetIamPolicyInterconnectAttachmentGroupRequest,
    GetIamPolicyInterconnectGroupRequest,
    GetIamPolicyLicenseRequest,
    GetIamPolicyMachineImageRequest,
    GetIamPolicyNetworkAttachmentRequest,
    GetIamPolicyNetworkFirewallPolicyRequest,
    GetIamPolicyNodeGroupRequest,
    GetIamPolicyNodeTemplateRequest,
    GetIamPolicyRegionBackendServiceRequest,
    GetIamPolicyRegionDiskRequest,
    GetIamPolicyRegionInstantSnapshotRequest,
    GetIamPolicyRegionNetworkFirewallPolicyRequest,
    GetIamPolicyRegionSnapshotRequest,
    GetIamPolicyReservationRequest,
    GetIamPolicyResourcePolicyRequest,
    GetIamPolicyServiceAttachmentRequest,
    GetIamPolicySnapshotRequest,
    GetIamPolicyStoragePoolRequest,
    GetIamPolicySubnetworkRequest,
    GetImageFamilyViewRequest,
    GetImageRequest,
    GetInstanceGroupManagerRequest,
    GetInstanceGroupManagerResizeRequestRequest,
    GetInstanceGroupRequest,
    GetInstanceRequest,
    GetInstanceSettingRequest,
    GetInstanceTemplateRequest,
    GetInstantSnapshotRequest,
    GetInterconnectAttachmentGroupRequest,
    GetInterconnectAttachmentRequest,
    GetInterconnectGroupRequest,
    GetInterconnectLocationRequest,
    GetInterconnectRemoteLocationRequest,
    GetInterconnectRequest,
    GetLicenseCodeRequest,
    GetLicenseRequest,
    GetMachineImageRequest,
    GetMachineTypeRequest,
    GetMacsecConfigInterconnectRequest,
    GetNatIpInfoRouterRequest,
    GetNatMappingInfoRoutersRequest,
    GetNetworkAttachmentRequest,
    GetNetworkEdgeSecurityServiceRequest,
    GetNetworkEndpointGroupRequest,
    GetNetworkFirewallPolicyRequest,
    GetNetworkProfileRequest,
    GetNetworkRequest,
    GetNodeGroupRequest,
    GetNodeTemplateRequest,
    GetNodeTypeRequest,
    GetOperationalStatusInterconnectAttachmentGroupRequest,
    GetOperationalStatusInterconnectGroupRequest,
    GetOrganizationSecurityPolicyRequest,
    GetPacketMirroringRequest,
    GetPacketMirroringRuleFirewallPolicyRequest,
    GetPacketMirroringRuleNetworkFirewallPolicyRequest,
    GetPartnerMetadataInstanceRequest,
    GetPreviewFeatureRequest,
    GetProjectRequest,
    GetPublicAdvertisedPrefixeRequest,
    GetPublicDelegatedPrefixeRequest,
    GetRegionAutoscalerRequest,
    GetRegionBackendServiceRequest,
    GetRegionCommitmentRequest,
    GetRegionDiskRequest,
    GetRegionDiskSettingRequest,
    GetRegionDiskTypeRequest,
    GetRegionHealthCheckRequest,
    GetRegionHealthCheckServiceRequest,
    GetRegionInstanceGroupManagerRequest,
    GetRegionInstanceGroupManagerResizeRequestRequest,
    GetRegionInstanceGroupRequest,
    GetRegionInstanceTemplateRequest,
    GetRegionInstantSnapshotRequest,
    GetRegionMultiMigRequest,
    GetRegionNetworkEndpointGroupRequest,
    GetRegionNetworkFirewallPolicyRequest,
    GetRegionNotificationEndpointRequest,
    GetRegionOperationRequest,
    GetRegionRequest,
    GetRegionSecurityPolicyRequest,
    GetRegionSnapshotRequest,
    GetRegionSnapshotSettingRequest,
    GetRegionSslCertificateRequest,
    GetRegionSslPolicyRequest,
    GetRegionTargetHttpProxyRequest,
    GetRegionTargetHttpsProxyRequest,
    GetRegionTargetTcpProxyRequest,
    GetRegionUrlMapRequest,
    GetReservationBlockRequest,
    GetReservationRequest,
    GetResourcePolicyRequest,
    GetRoutePolicyRouterRequest,
    GetRouteRequest,
    GetRouterRequest,
    GetRouterStatusRouterRequest,
    GetRuleFirewallPolicyRequest,
    GetRuleNetworkFirewallPolicyRequest,
    GetRuleOrganizationSecurityPolicyRequest,
    GetRuleRegionNetworkFirewallPolicyRequest,
    GetRuleRegionSecurityPolicyRequest,
    GetRuleSecurityPolicyRequest,
    GetScreenshotInstanceRequest,
    GetSecurityPolicyRequest,
    GetSerialPortOutputInstanceRequest,
    GetServiceAttachmentRequest,
    GetShieldedInstanceIdentityInstanceRequest,
    GetShieldedVmIdentityInstanceRequest,
    GetSnapshotRequest,
    GetSnapshotSettingRequest,
    GetSslCertificateRequest,
    GetSslPolicyRequest,
    GetStatusVpnGatewayRequest,
    GetStoragePoolRequest,
    GetStoragePoolTypeRequest,
    GetSubnetworkRequest,
    GetTargetGrpcProxyRequest,
    GetTargetHttpProxyRequest,
    GetTargetHttpsProxyRequest,
    GetTargetInstanceRequest,
    GetTargetPoolRequest,
    GetTargetSslProxyRequest,
    GetTargetTcpProxyRequest,
    GetTargetVpnGatewayRequest,
    GetUrlMapRequest,
    GetVpnGatewayRequest,
    GetVpnTunnelRequest,
    GetWireGroupRequest,
    GetXpnHostProjectRequest,
    GetXpnResourcesProjectsRequest,
    GetZoneOperationRequest,
    GetZoneRequest,
    GlobalAddressesMoveRequest,
    GlobalNetworkEndpointGroupsAttachEndpointsRequest,
    GlobalNetworkEndpointGroupsDetachEndpointsRequest,
    GlobalOrganizationSetPolicyRequest,
    GlobalSetLabelsRequest,
    GlobalSetPolicyRequest,
    GroupMaintenanceInfo,
    GRPCHealthCheck,
    GRPCTLSHealthCheck,
    GuestAttributes,
    GuestAttributesEntry,
    GuestAttributesValue,
    GuestOsFeature,
    HealthCheck,
    HealthCheckList,
    HealthCheckLogConfig,
    HealthCheckReference,
    HealthChecksAggregatedList,
    HealthCheckService,
    HealthCheckServiceReference,
    HealthCheckServicesList,
    HealthChecksScopedList,
    HealthStatus,
    HealthStatusForNetworkEndpoint,
    Help,
    HelpLink,
    HostRule,
    HTTP2HealthCheck,
    HttpFaultAbort,
    HttpFaultDelay,
    HttpFaultInjection,
    HttpFilterConfig,
    HttpHeaderAction,
    HttpHeaderMatch,
    HttpHeaderOption,
    HTTPHealthCheck,
    HttpQueryParameterMatch,
    HttpRedirectAction,
    HttpRetryPolicy,
    HttpRouteAction,
    HttpRouteRule,
    HttpRouteRuleMatch,
    HTTPSHealthCheck,
    Image,
    ImageFamilyView,
    ImageList,
    InitialStateConfig,
    InsertAddressRequest,
    InsertAutoscalerRequest,
    InsertBackendBucketRequest,
    InsertBackendServiceRequest,
    InsertCrossSiteNetworkRequest,
    InsertDiskRequest,
    InsertExternalVpnGatewayRequest,
    InsertFirewallPolicyRequest,
    InsertFirewallRequest,
    InsertForwardingRuleRequest,
    InsertFutureReservationRequest,
    InsertGlobalAddressRequest,
    InsertGlobalForwardingRuleRequest,
    InsertGlobalNetworkEndpointGroupRequest,
    InsertGlobalPublicDelegatedPrefixeRequest,
    InsertHealthCheckRequest,
    InsertImageRequest,
    InsertInstanceGroupManagerRequest,
    InsertInstanceGroupManagerResizeRequestRequest,
    InsertInstanceGroupRequest,
    InsertInstanceRequest,
    InsertInstanceTemplateRequest,
    InsertInstantSnapshotRequest,
    InsertInterconnectAttachmentGroupRequest,
    InsertInterconnectAttachmentRequest,
    InsertInterconnectGroupRequest,
    InsertInterconnectRequest,
    InsertLicenseRequest,
    InsertMachineImageRequest,
    InsertNetworkAttachmentRequest,
    InsertNetworkEdgeSecurityServiceRequest,
    InsertNetworkEndpointGroupRequest,
    InsertNetworkFirewallPolicyRequest,
    InsertNetworkRequest,
    InsertNodeGroupRequest,
    InsertNodeTemplateRequest,
    InsertOrganizationSecurityPolicyRequest,
    InsertPacketMirroringRequest,
    InsertPublicAdvertisedPrefixeRequest,
    InsertPublicDelegatedPrefixeRequest,
    InsertRegionAutoscalerRequest,
    InsertRegionBackendServiceRequest,
    InsertRegionCommitmentRequest,
    InsertRegionDiskRequest,
    InsertRegionHealthCheckRequest,
    InsertRegionHealthCheckServiceRequest,
    InsertRegionInstanceGroupManagerRequest,
    InsertRegionInstanceGroupManagerResizeRequestRequest,
    InsertRegionInstanceTemplateRequest,
    InsertRegionInstantSnapshotRequest,
    InsertRegionMultiMigRequest,
    InsertRegionNetworkEndpointGroupRequest,
    InsertRegionNetworkFirewallPolicyRequest,
    InsertRegionNotificationEndpointRequest,
    InsertRegionSecurityPolicyRequest,
    InsertRegionSnapshotRequest,
    InsertRegionSslCertificateRequest,
    InsertRegionSslPolicyRequest,
    InsertRegionTargetHttpProxyRequest,
    InsertRegionTargetHttpsProxyRequest,
    InsertRegionTargetTcpProxyRequest,
    InsertRegionUrlMapRequest,
    InsertReservationRequest,
    InsertResourcePolicyRequest,
    InsertRouteRequest,
    InsertRouterRequest,
    InsertSecurityPolicyRequest,
    InsertServiceAttachmentRequest,
    InsertSnapshotRequest,
    InsertSslCertificateRequest,
    InsertSslPolicyRequest,
    InsertStoragePoolRequest,
    InsertSubnetworkRequest,
    InsertTargetGrpcProxyRequest,
    InsertTargetHttpProxyRequest,
    InsertTargetHttpsProxyRequest,
    InsertTargetInstanceRequest,
    InsertTargetPoolRequest,
    InsertTargetSslProxyRequest,
    InsertTargetTcpProxyRequest,
    InsertTargetVpnGatewayRequest,
    InsertUrlMapRequest,
    InsertVpnGatewayRequest,
    InsertVpnTunnelRequest,
    InsertWireGroupRequest,
    Instance,
    InstanceAggregatedList,
    InstanceConsumptionData,
    InstanceConsumptionInfo,
    InstanceGroup,
    InstanceGroupAggregatedList,
    InstanceGroupList,
    InstanceGroupManager,
    InstanceGroupManagerActionsSummary,
    InstanceGroupManagerAggregatedList,
    InstanceGroupManagerAllInstancesConfig,
    InstanceGroupManagerAutoHealingPolicy,
    InstanceGroupManagerInstanceFlexibilityPolicy,
    InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection,
    InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix,
    InstanceGroupManagerInstanceLifecyclePolicy,
    InstanceGroupManagerList,
    InstanceGroupManagerParams,
    InstanceGroupManagerResizeRequest,
    InstanceGroupManagerResizeRequestsListResponse,
    InstanceGroupManagerResizeRequestStatus,
    InstanceGroupManagerResizeRequestStatusLastAttempt,
    InstanceGroupManagerResourcePolicies,
    InstanceGroupManagersAbandonInstancesRequest,
    InstanceGroupManagersApplyUpdatesRequest,
    InstanceGroupManagersCreateInstancesRequest,
    InstanceGroupManagersDeleteInstancesRequest,
    InstanceGroupManagersDeletePerInstanceConfigsReq,
    InstanceGroupManagersListErrorsResponse,
    InstanceGroupManagersListManagedInstancesResponse,
    InstanceGroupManagersListPerInstanceConfigsResp,
    InstanceGroupManagersPatchPerInstanceConfigsReq,
    InstanceGroupManagersRecreateInstancesRequest,
    InstanceGroupManagersResizeAdvancedRequest,
    InstanceGroupManagersResumeInstancesRequest,
    InstanceGroupManagersScopedList,
    InstanceGroupManagersSetAutoHealingRequest,
    InstanceGroupManagersSetInstanceTemplateRequest,
    InstanceGroupManagersSetTargetPoolsRequest,
    InstanceGroupManagersStartInstancesRequest,
    InstanceGroupManagersStopInstancesRequest,
    InstanceGroupManagersSuspendInstancesRequest,
    InstanceGroupManagerStandbyPolicy,
    InstanceGroupManagerStatus,
    InstanceGroupManagerStatusAllInstancesConfig,
    InstanceGroupManagerStatusBulkInstanceOperation,
    InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck,
    InstanceGroupManagerStatusStateful,
    InstanceGroupManagerStatusStatefulPerInstanceConfigs,
    InstanceGroupManagerStatusVersionTarget,
    InstanceGroupManagersUpdatePerInstanceConfigsReq,
    InstanceGroupManagerTargetSizePolicy,
    InstanceGroupManagerUpdatePolicy,
    InstanceGroupManagerVersion,
    InstanceGroupsAddInstancesRequest,
    InstanceGroupsListInstances,
    InstanceGroupsListInstancesRequest,
    InstanceGroupsRemoveInstancesRequest,
    InstanceGroupsScopedList,
    InstanceGroupsSetNamedPortsRequest,
    InstanceList,
    InstanceListReferrers,
    InstanceManagedByIgmError,
    InstanceManagedByIgmErrorInstanceActionDetails,
    InstanceManagedByIgmErrorManagedInstanceError,
    InstanceMoveRequest,
    InstanceParams,
    InstanceProperties,
    InstancePropertiesPatch,
    InstanceReference,
    InstancesAddResourcePoliciesRequest,
    InstancesBulkInsertOperationMetadata,
    InstanceSettings,
    InstanceSettingsMetadata,
    InstancesGetEffectiveFirewallsResponse,
    InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy,
    InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy,
    InstancesRemoveResourcePoliciesRequest,
    InstancesReportHostAsFaultyRequest,
    InstancesReportHostAsFaultyRequestFaultReason,
    InstancesResumeRequest,
    InstancesScopedList,
    InstancesSetLabelsRequest,
    InstancesSetMachineResourcesRequest,
    InstancesSetMachineTypeRequest,
    InstancesSetMinCpuPlatformRequest,
    InstancesSetNameRequest,
    InstancesSetSecurityPolicyRequest,
    InstancesSetServiceAccountRequest,
    InstancesStartWithEncryptionKeyRequest,
    InstanceTemplate,
    InstanceTemplateAggregatedList,
    InstanceTemplateList,
    InstanceTemplatesScopedList,
    InstanceWithNamedPorts,
    InstantSnapshot,
    InstantSnapshotAggregatedList,
    InstantSnapshotList,
    InstantSnapshotResourceStatus,
    InstantSnapshotsScopedList,
    Int64RangeMatch,
    Interconnect,
    InterconnectApplicationAwareInterconnect,
    InterconnectApplicationAwareInterconnectBandwidthPercentage,
    InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy,
    InterconnectApplicationAwareInterconnectStrictPriorityPolicy,
    InterconnectAttachment,
    InterconnectAttachmentAggregatedList,
    InterconnectAttachmentConfigurationConstraints,
    InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange,
    InterconnectAttachmentGroup,
    InterconnectAttachmentGroupAttachment,
    InterconnectAttachmentGroupConfigured,
    InterconnectAttachmentGroupConfiguredAvailabilitySLA,
    InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers,
    InterconnectAttachmentGroupIntent,
    InterconnectAttachmentGroupLogicalStructure,
    InterconnectAttachmentGroupLogicalStructureRegion,
    InterconnectAttachmentGroupLogicalStructureRegionMetro,
    InterconnectAttachmentGroupLogicalStructureRegionMetroFacility,
    InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone,
    InterconnectAttachmentGroupsGetOperationalStatusResponse,
    InterconnectAttachmentGroupsListResponse,
    InterconnectAttachmentGroupsOperationalStatus,
    InterconnectAttachmentGroupsOperationalStatusAttachmentStatus,
    InterconnectAttachmentList,
    InterconnectAttachmentPartnerMetadata,
    InterconnectAttachmentPrivateInfo,
    InterconnectAttachmentsScopedList,
    InterconnectCircuitInfo,
    InterconnectDiagnostics,
    InterconnectDiagnosticsARPEntry,
    InterconnectDiagnosticsLinkLACPStatus,
    InterconnectDiagnosticsLinkOpticalPower,
    InterconnectDiagnosticsLinkStatus,
    InterconnectDiagnosticsMacsecStatus,
    InterconnectGroup,
    InterconnectGroupConfigured,
    InterconnectGroupConfiguredTopologyCapability,
    InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers,
    InterconnectGroupIntent,
    InterconnectGroupInterconnect,
    InterconnectGroupPhysicalStructure,
    InterconnectGroupPhysicalStructureMetros,
    InterconnectGroupPhysicalStructureMetrosFacilities,
    InterconnectGroupPhysicalStructureMetrosFacilitiesZones,
    InterconnectGroupsCreateMembers,
    InterconnectGroupsCreateMembersInterconnectInput,
    InterconnectGroupsCreateMembersRequest,
    InterconnectGroupsGetOperationalStatusResponse,
    InterconnectGroupsListResponse,
    InterconnectGroupsOperationalStatus,
    InterconnectGroupsOperationalStatusInterconnectStatus,
    InterconnectList,
    InterconnectLocation,
    InterconnectLocationCrossSiteInterconnectInfo,
    InterconnectLocationList,
    InterconnectLocationRegionInfo,
    InterconnectMacsec,
    InterconnectMacsecConfig,
    InterconnectMacsecConfigPreSharedKey,
    InterconnectMacsecPreSharedKey,
    InterconnectOutageNotification,
    InterconnectRemoteLocation,
    InterconnectRemoteLocationConstraints,
    InterconnectRemoteLocationConstraintsSubnetLengthRange,
    InterconnectRemoteLocationList,
    InterconnectRemoteLocationPermittedConnections,
    InterconnectsGetDiagnosticsResponse,
    InterconnectsGetMacsecConfigResponse,
    InvalidateCacheRegionUrlMapRequest,
    InvalidateCacheUrlMapRequest,
    Items,
    License,
    LicenseCode,
    LicenseCodeLicenseAlias,
    LicenseResourceCommitment,
    LicenseResourceRequirements,
    LicensesListResponse,
    ListAcceleratorTypesRequest,
    ListAddressesRequest,
    ListAssociationsFirewallPolicyRequest,
    ListAssociationsOrganizationSecurityPolicyRequest,
    ListAutoscalersRequest,
    ListAvailableFeaturesRegionSslPoliciesRequest,
    ListAvailableFeaturesSslPoliciesRequest,
    ListBackendBucketsRequest,
    ListBackendServicesRequest,
    ListBgpRoutesRoutersRequest,
    ListCrossSiteNetworksRequest,
    ListDisksRequest,
    ListDisksStoragePoolsRequest,
    ListDiskTypesRequest,
    ListErrorsInstanceGroupManagersRequest,
    ListErrorsRegionInstanceGroupManagersRequest,
    ListExternalVpnGatewaysRequest,
    ListFirewallPoliciesRequest,
    ListFirewallsRequest,
    ListForwardingRulesRequest,
    ListFutureReservationsRequest,
    ListGlobalAddressesRequest,
    ListGlobalForwardingRulesRequest,
    ListGlobalNetworkEndpointGroupsRequest,
    ListGlobalOperationsRequest,
    ListGlobalOrganizationOperationsRequest,
    ListGlobalPublicDelegatedPrefixesRequest,
    ListHealthChecksRequest,
    ListImagesRequest,
    ListInstanceGroupManagerResizeRequestsRequest,
    ListInstanceGroupManagersRequest,
    ListInstanceGroupsRequest,
    ListInstancesInstanceGroupsRequest,
    ListInstancesRegionInstanceGroupsRequest,
    ListInstancesRequest,
    ListInstanceTemplatesRequest,
    ListInstantSnapshotsRequest,
    ListInterconnectAttachmentGroupsRequest,
    ListInterconnectAttachmentsRequest,
    ListInterconnectGroupsRequest,
    ListInterconnectLocationsRequest,
    ListInterconnectRemoteLocationsRequest,
    ListInterconnectsRequest,
    ListLicensesRequest,
    ListMachineImagesRequest,
    ListMachineTypesRequest,
    ListManagedInstancesInstanceGroupManagersRequest,
    ListManagedInstancesRegionInstanceGroupManagersRequest,
    ListNetworkAttachmentsRequest,
    ListNetworkEndpointGroupsRequest,
    ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest,
    ListNetworkEndpointsNetworkEndpointGroupsRequest,
    ListNetworkEndpointsRegionNetworkEndpointGroupsRequest,
    ListNetworkFirewallPoliciesRequest,
    ListNetworkProfilesRequest,
    ListNetworksRequest,
    ListNodeGroupsRequest,
    ListNodesNodeGroupsRequest,
    ListNodeTemplatesRequest,
    ListNodeTypesRequest,
    ListOrganizationSecurityPoliciesRequest,
    ListPacketMirroringsRequest,
    ListPeeringRoutesNetworksRequest,
    ListPerInstanceConfigsInstanceGroupManagersRequest,
    ListPerInstanceConfigsRegionInstanceGroupManagersRequest,
    ListPreconfiguredExpressionSetsOrganizationSecurityPoliciesRequest,
    ListPreconfiguredExpressionSetsSecurityPoliciesRequest,
    ListPreviewFeaturesRequest,
    ListPublicAdvertisedPrefixesRequest,
    ListPublicDelegatedPrefixesRequest,
    ListReferrersInstancesRequest,
    ListRegionAutoscalersRequest,
    ListRegionBackendServicesRequest,
    ListRegionCommitmentsRequest,
    ListRegionDisksRequest,
    ListRegionDiskTypesRequest,
    ListRegionHealthCheckServicesRequest,
    ListRegionHealthChecksRequest,
    ListRegionInstanceGroupManagerResizeRequestsRequest,
    ListRegionInstanceGroupManagersRequest,
    ListRegionInstanceGroupsRequest,
    ListRegionInstanceTemplatesRequest,
    ListRegionInstantSnapshotsRequest,
    ListRegionMultiMigsRequest,
    ListRegionNetworkEndpointGroupsRequest,
    ListRegionNetworkFirewallPoliciesRequest,
    ListRegionNotificationEndpointsRequest,
    ListRegionOperationsRequest,
    ListRegionSecurityPoliciesRequest,
    ListRegionSnapshotsRequest,
    ListRegionsRequest,
    ListRegionSslCertificatesRequest,
    ListRegionSslPoliciesRequest,
    ListRegionTargetHttpProxiesRequest,
    ListRegionTargetHttpsProxiesRequest,
    ListRegionTargetTcpProxiesRequest,
    ListRegionUrlMapsRequest,
    ListRegionZonesRequest,
    ListReservationBlocksRequest,
    ListReservationsRequest,
    ListResourcePoliciesRequest,
    ListRoutePoliciesRoutersRequest,
    ListRoutersRequest,
    ListRoutesRequest,
    ListSecurityPoliciesRequest,
    ListServiceAttachmentsRequest,
    ListSnapshotsRequest,
    ListSslCertificatesRequest,
    ListSslPoliciesRequest,
    ListStoragePoolsRequest,
    ListStoragePoolTypesRequest,
    ListSubnetworksRequest,
    ListTargetGrpcProxiesRequest,
    ListTargetHttpProxiesRequest,
    ListTargetHttpsProxiesRequest,
    ListTargetInstancesRequest,
    ListTargetPoolsRequest,
    ListTargetSslProxiesRequest,
    ListTargetTcpProxiesRequest,
    ListTargetVpnGatewaysRequest,
    ListUrlMapsRequest,
    ListUsableBackendBucketsRequest,
    ListUsableBackendServicesRequest,
    ListUsableRegionBackendServicesRequest,
    ListUsableSubnetworksRequest,
    ListVpnGatewaysRequest,
    ListVpnTunnelsRequest,
    ListWireGroupsRequest,
    ListXpnHostsProjectsRequest,
    ListZoneOperationsRequest,
    ListZonesRequest,
    LocalDisk,
    LocalizedMessage,
    LocationPolicy,
    LocationPolicyLocation,
    LocationPolicyLocationConstraints,
    MachineImage,
    MachineImageList,
    MachineType,
    MachineTypeAggregatedList,
    MachineTypeList,
    MachineTypesScopedList,
    ManagedInstance,
    ManagedInstanceAllInstancesConfig,
    ManagedInstanceInstanceHealth,
    ManagedInstanceLastAttempt,
    ManagedInstanceLastAttemptErrors,
    ManagedInstancePropertiesFromFlexibilityPolicy,
    ManagedInstanceVersion,
    Metadata,
    MetadataFilter,
    MetadataFilterLabelMatch,
    MoveAddressRequest,
    MoveDiskProjectRequest,
    MoveFirewallPolicyRequest,
    MoveGlobalAddressRequest,
    MoveInstanceProjectRequest,
    MoveOrganizationSecurityPolicyRequest,
    MultiMig,
    MultiMigResourcePolicies,
    MultiMigsList,
    NamedPort,
    NatIpInfo,
    NatIpInfoNatIpInfoMapping,
    NatIpInfoResponse,
    Network,
    NetworkAttachment,
    NetworkAttachmentAggregatedList,
    NetworkAttachmentConnectedEndpoint,
    NetworkAttachmentList,
    NetworkAttachmentsScopedList,
    NetworkEdgeSecurityService,
    NetworkEdgeSecurityServiceAggregatedList,
    NetworkEdgeSecurityServicesScopedList,
    NetworkEndpoint,
    NetworkEndpointGroup,
    NetworkEndpointGroupAggregatedList,
    NetworkEndpointGroupAppEngine,
    NetworkEndpointGroupCloudFunction,
    NetworkEndpointGroupCloudRun,
    NetworkEndpointGroupLbNetworkEndpointGroup,
    NetworkEndpointGroupList,
    NetworkEndpointGroupPscData,
    NetworkEndpointGroupsAttachEndpointsRequest,
    NetworkEndpointGroupsDetachEndpointsRequest,
    NetworkEndpointGroupServerlessDeployment,
    NetworkEndpointGroupsListEndpointsRequest,
    NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter,
    NetworkEndpointGroupsListNetworkEndpoints,
    NetworkEndpointGroupsScopedList,
    NetworkEndpointWithHealthStatus,
    NetworkFirewallPolicyAggregatedList,
    NetworkInterface,
    NetworkList,
    NetworkParams,
    NetworkPeering,
    NetworkPeeringConnectionStatus,
    NetworkPeeringConnectionStatusConsensusState,
    NetworkPeeringConnectionStatusTrafficConfiguration,
    NetworkPerformanceConfig,
    NetworkProfile,
    NetworkProfileLocation,
    NetworkProfileNetworkFeatures,
    NetworkProfilesListResponse,
    NetworkRoutingConfig,
    NetworksAddPeeringRequest,
    NetworksGetEffectiveFirewallsResponse,
    NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy,
    NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy,
    NetworksRemovePeeringRequest,
    NetworksRequestRemovePeeringRequest,
    NetworksUpdatePeeringRequest,
    NodeGroup,
    NodeGroupAggregatedList,
    NodeGroupAutoscalingPolicy,
    NodeGroupList,
    NodeGroupMaintenanceWindow,
    NodeGroupNode,
    NodeGroupsAddNodesRequest,
    NodeGroupsDeleteNodesRequest,
    NodeGroupsListNodes,
    NodeGroupsPerformMaintenanceRequest,
    NodeGroupsScopedList,
    NodeGroupsSetNodeTemplateRequest,
    NodeGroupsSimulateMaintenanceEventRequest,
    NodeTemplate,
    NodeTemplateAggregatedList,
    NodeTemplateList,
    NodeTemplateNodeTypeFlexibility,
    NodeTemplatesScopedList,
    NodeType,
    NodeTypeAggregatedList,
    NodeTypeList,
    NodeTypesScopedList,
    NotificationEndpoint,
    NotificationEndpointGrpcSettings,
    NotificationEndpointList,
    Operation,
    OperationAggregatedList,
    OperationList,
    OperationsScopedList,
    OrganizationSecurityPoliciesListAssociationsResponse,
    OutlierDetection,
    PacketIntervals,
    PacketMirroring,
    PacketMirroringAggregatedList,
    PacketMirroringFilter,
    PacketMirroringForwardingRuleInfo,
    PacketMirroringList,
    PacketMirroringMirroredResourceInfo,
    PacketMirroringMirroredResourceInfoInstanceInfo,
    PacketMirroringMirroredResourceInfoSubnetInfo,
    PacketMirroringNetworkInfo,
    PacketMirroringsScopedList,
    PartnerMetadata,
    PatchAssociationRegionNetworkFirewallPolicyRequest,
    PatchAutoscalerRequest,
    PatchBackendBucketRequest,
    PatchBackendServiceRequest,
    PatchCrossSiteNetworkRequest,
    PatchDiskSettingRequest,
    PatchFirewallPolicyRequest,
    PatchFirewallRequest,
    PatchForwardingRuleRequest,
    PatchGlobalForwardingRuleRequest,
    PatchGlobalPublicDelegatedPrefixeRequest,
    PatchHealthCheckRequest,
    PatchImageRequest,
    PatchInstanceGroupManagerRequest,
    PatchInstanceSettingRequest,
    PatchInterconnectAttachmentGroupRequest,
    PatchInterconnectAttachmentRequest,
    PatchInterconnectGroupRequest,
    PatchInterconnectRequest,
    PatchNetworkAttachmentRequest,
    PatchNetworkEdgeSecurityServiceRequest,
    PatchNetworkFirewallPolicyRequest,
    PatchNetworkRequest,
    PatchNodeGroupRequest,
    PatchOrganizationSecurityPolicyRequest,
    PatchPacketMirroringRequest,
    PatchPacketMirroringRuleFirewallPolicyRequest,
    PatchPacketMirroringRuleNetworkFirewallPolicyRequest,
    PatchPartnerMetadataInstanceRequest,
    PatchPerInstanceConfigsInstanceGroupManagerRequest,
    PatchPerInstanceConfigsRegionInstanceGroupManagerRequest,
    PatchPublicAdvertisedPrefixeRequest,
    PatchPublicDelegatedPrefixeRequest,
    PatchRegionAutoscalerRequest,
    PatchRegionBackendServiceRequest,
    PatchRegionDiskSettingRequest,
    PatchRegionHealthCheckRequest,
    PatchRegionHealthCheckServiceRequest,
    PatchRegionInstanceGroupManagerRequest,
    PatchRegionNetworkFirewallPolicyRequest,
    PatchRegionSecurityPolicyRequest,
    PatchRegionSnapshotSettingRequest,
    PatchRegionSslPolicyRequest,
    PatchRegionTargetHttpsProxyRequest,
    PatchRegionUrlMapRequest,
    PatchResourcePolicyRequest,
    PatchRoutePolicyRouterRequest,
    PatchRouterRequest,
    PatchRuleFirewallPolicyRequest,
    PatchRuleNetworkFirewallPolicyRequest,
    PatchRuleOrganizationSecurityPolicyRequest,
    PatchRuleRegionNetworkFirewallPolicyRequest,
    PatchRuleRegionSecurityPolicyRequest,
    PatchRuleSecurityPolicyRequest,
    PatchSecurityPolicyRequest,
    PatchServiceAttachmentRequest,
    PatchSnapshotSettingRequest,
    PatchSslPolicyRequest,
    PatchSubnetworkRequest,
    PatchTargetGrpcProxyRequest,
    PatchTargetHttpProxyRequest,
    PatchTargetHttpsProxyRequest,
    PatchUrlMapRequest,
    PatchWireGroupRequest,
    PathMatcher,
    PathRule,
    PerformMaintenanceInstanceRequest,
    PerformMaintenanceNodeGroupRequest,
    PerformMaintenanceReservationBlockRequest,
    PerformMaintenanceReservationRequest,
    PerInstanceConfig,
    Policy,
    PreconfiguredWafSet,
    PreservedState,
    PreservedStatePreservedDisk,
    PreservedStatePreservedNetworkIp,
    PreservedStatePreservedNetworkIpIpAddress,
    PreviewFeature,
    PreviewFeatureList,
    PreviewFeatureRolloutOperation,
    PreviewFeatureRolloutOperationRolloutInput,
    PreviewFeatureRolloutOperationRolloutStatus,
    PreviewFeatureRolloutOperationRolloutStatusRolloutMetadata,
    PreviewFeatureStatus,
    PreviewFeatureStatusReleaseStatus,
    PreviewRouterRequest,
    Project,
    ProjectsDisableXpnResourceRequest,
    ProjectsEnableXpnResourceRequest,
    ProjectsGetXpnResources,
    ProjectsListXpnHostsRequest,
    ProjectsSetCloudArmorTierRequest,
    ProjectsSetDefaultNetworkTierRequest,
    ProjectsSetManagedProtectionTierRequest,
    PublicAdvertisedPrefix,
    PublicAdvertisedPrefixList,
    PublicAdvertisedPrefixPublicDelegatedPrefix,
    PublicDelegatedPrefix,
    PublicDelegatedPrefixAggregatedList,
    PublicDelegatedPrefixesScopedList,
    PublicDelegatedPrefixList,
    PublicDelegatedPrefixPublicDelegatedSubPrefix,
    Quota,
    QuotaExceededInfo,
    QuotaStatusWarning,
    RawDisk,
    RecreateInstancesInstanceGroupManagerRequest,
    RecreateInstancesRegionInstanceGroupManagerRequest,
    Reference,
    Region,
    RegionAddressesMoveRequest,
    RegionAutoscalerList,
    RegionCommitmentsUpdateReservationsRequest,
    RegionDisksAddResourcePoliciesRequest,
    RegionDisksRemoveResourcePoliciesRequest,
    RegionDisksResizeRequest,
    RegionDisksStartAsyncReplicationRequest,
    RegionDiskTypeList,
    RegionInstanceGroupList,
    RegionInstanceGroupManagerDeleteInstanceConfigReq,
    RegionInstanceGroupManagerList,
    RegionInstanceGroupManagerPatchInstanceConfigReq,
    RegionInstanceGroupManagerResizeRequestsListResponse,
    RegionInstanceGroupManagersAbandonInstancesRequest,
    RegionInstanceGroupManagersApplyUpdatesRequest,
    RegionInstanceGroupManagersCreateInstancesRequest,
    RegionInstanceGroupManagersDeleteInstancesRequest,
    RegionInstanceGroupManagersListErrorsResponse,
    RegionInstanceGroupManagersListInstanceConfigsResp,
    RegionInstanceGroupManagersListInstancesResponse,
    RegionInstanceGroupManagersRecreateRequest,
    RegionInstanceGroupManagersResizeAdvancedRequest,
    RegionInstanceGroupManagersResumeInstancesRequest,
    RegionInstanceGroupManagersSetAutoHealingRequest,
    RegionInstanceGroupManagersSetTargetPoolsRequest,
    RegionInstanceGroupManagersSetTemplateRequest,
    RegionInstanceGroupManagersStartInstancesRequest,
    RegionInstanceGroupManagersStopInstancesRequest,
    RegionInstanceGroupManagersSuspendInstancesRequest,
    RegionInstanceGroupManagerUpdateInstanceConfigReq,
    RegionInstanceGroupsListInstances,
    RegionInstanceGroupsListInstancesRequest,
    RegionInstanceGroupsSetNamedPortsRequest,
    RegionList,
    RegionNetworkEndpointGroupsAttachEndpointsRequest,
    RegionNetworkEndpointGroupsDetachEndpointsRequest,
    RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse,
    RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy,
    RegionSetLabelsRequest,
    RegionSetPolicyRequest,
    RegionTargetHttpsProxiesSetSslCertificatesRequest,
    RegionUrlMapsValidateRequest,
    RemoveAssociationFirewallPolicyRequest,
    RemoveAssociationNetworkFirewallPolicyRequest,
    RemoveAssociationOrganizationSecurityPolicyRequest,
    RemoveAssociationRegionNetworkFirewallPolicyRequest,
    RemoveHealthCheckTargetPoolRequest,
    RemoveInstancesInstanceGroupRequest,
    RemoveInstanceTargetPoolRequest,
    RemovePacketMirroringRuleFirewallPolicyRequest,
    RemovePacketMirroringRuleNetworkFirewallPolicyRequest,
    RemovePeeringNetworkRequest,
    RemoveResourcePoliciesDiskRequest,
    RemoveResourcePoliciesInstanceRequest,
    RemoveResourcePoliciesRegionDiskRequest,
    RemoveRuleFirewallPolicyRequest,
    RemoveRuleNetworkFirewallPolicyRequest,
    RemoveRuleOrganizationSecurityPolicyRequest,
    RemoveRuleRegionNetworkFirewallPolicyRequest,
    RemoveRuleRegionSecurityPolicyRequest,
    RemoveRuleSecurityPolicyRequest,
    ReportHostAsFaultyInstanceRequest,
    RequestMirrorPolicy,
    RequestRemovePeeringNetworkRequest,
    Reservation,
    ReservationAffinity,
    ReservationAggregatedList,
    ReservationBlock,
    ReservationBlockPhysicalTopology,
    ReservationBlocksGetResponse,
    ReservationBlocksListResponse,
    ReservationList,
    ReservationsBlocksPerformMaintenanceRequest,
    ReservationsPerformMaintenanceRequest,
    ReservationsResizeRequest,
    ReservationsScopedList,
    ResetInstanceRequest,
    ResizeAdvancedInstanceGroupManagerRequest,
    ResizeAdvancedRegionInstanceGroupManagerRequest,
    ResizeDiskRequest,
    ResizeInstanceGroupManagerRequest,
    ResizeRegionDiskRequest,
    ResizeRegionInstanceGroupManagerRequest,
    ResizeReservationRequest,
    ResourceCommitment,
    ResourceGroupReference,
    ResourcePoliciesScopedList,
    ResourcePolicy,
    ResourcePolicyAggregatedList,
    ResourcePolicyDailyCycle,
    ResourcePolicyDiskConsistencyGroupPolicy,
    ResourcePolicyGroupPlacementPolicy,
    ResourcePolicyHourlyCycle,
    ResourcePolicyInstanceSchedulePolicy,
    ResourcePolicyInstanceSchedulePolicySchedule,
    ResourcePolicyList,
    ResourcePolicyResourceStatus,
    ResourcePolicyResourceStatusInstanceSchedulePolicyStatus,
    ResourcePolicySnapshotSchedulePolicy,
    ResourcePolicySnapshotSchedulePolicyRetentionPolicy,
    ResourcePolicySnapshotSchedulePolicySchedule,
    ResourcePolicySnapshotSchedulePolicySnapshotProperties,
    ResourcePolicyWeeklyCycle,
    ResourcePolicyWeeklyCycleDayOfWeek,
    ResourcePolicyWorkloadPolicy,
    ResourceStatus,
    ResourceStatusPhysicalHostTopology,
    ResourceStatusScheduling,
    ResourceStatusShutdownDetails,
    ResumeInstanceRequest,
    ResumeInstancesInstanceGroupManagerRequest,
    ResumeInstancesRegionInstanceGroupManagerRequest,
    RolloutPolicy,
    Route,
    RouteAsPath,
    RouteList,
    RouteParams,
    RoutePolicy,
    RoutePolicyPolicyTerm,
    Router,
    RouterAdvertisedIpRange,
    RouterAggregatedList,
    RouterBgp,
    RouterBgpPeer,
    RouterBgpPeerBfd,
    RouterBgpPeerCustomLearnedIpRange,
    RouterInterface,
    RouterList,
    RouterMd5AuthenticationKey,
    RouterNat,
    RouterNatLogConfig,
    RouterNatRule,
    RouterNatRuleAction,
    RouterNatSubnetworkToNat,
    RouterNatSubnetworkToNat64,
    RoutersGetRoutePolicyResponse,
    RoutersListBgpRoutes,
    RoutersListRoutePolicies,
    RoutersPreviewResponse,
    RoutersScopedList,
    RouterStatus,
    RouterStatusBgpPeerStatus,
    RouterStatusNatStatus,
    RouterStatusNatStatusNatRuleStatus,
    RouterStatusResponse,
    SavedAttachedDisk,
    SavedDisk,
    ScalingScheduleStatus,
    Scheduling,
    SchedulingGracefulShutdown,
    SchedulingNodeAffinity,
    SchedulingOnInstanceStopAction,
    Screenshot,
    SecurityPoliciesAggregatedList,
    SecurityPoliciesListPreconfiguredExpressionSetsResponse,
    SecurityPoliciesScopedList,
    SecurityPoliciesWafConfig,
    SecurityPolicy,
    SecurityPolicyAdaptiveProtectionConfig,
    SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig,
    SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig,
    SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig,
    SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig,
    SecurityPolicyAdvancedOptionsConfig,
    SecurityPolicyAdvancedOptionsConfigJsonCustomConfig,
    SecurityPolicyAssociation,
    SecurityPolicyDdosProtectionConfig,
    SecurityPolicyList,
    SecurityPolicyRecaptchaOptionsConfig,
    SecurityPolicyReference,
    SecurityPolicyRule,
    SecurityPolicyRuleHttpHeaderAction,
    SecurityPolicyRuleHttpHeaderActionHttpHeaderOption,
    SecurityPolicyRuleMatcher,
    SecurityPolicyRuleMatcherConfig,
    SecurityPolicyRuleMatcherConfigLayer4Config,
    SecurityPolicyRuleMatcherExprOptions,
    SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions,
    SecurityPolicyRuleNetworkMatcher,
    SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch,
    SecurityPolicyRulePreconfiguredWafConfig,
    SecurityPolicyRulePreconfiguredWafConfigExclusion,
    SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams,
    SecurityPolicyRuleRateLimitOptions,
    SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig,
    SecurityPolicyRuleRateLimitOptionsThreshold,
    SecurityPolicyRuleRedirectOptions,
    SecurityPolicyUserDefinedField,
    SecuritySettings,
    SendDiagnosticInterruptInstanceRequest,
    SendDiagnosticInterruptInstanceResponse,
    SerialPortOutput,
    ServerBinding,
    ServiceAccount,
    ServiceAttachment,
    ServiceAttachmentAggregatedList,
    ServiceAttachmentConnectedEndpoint,
    ServiceAttachmentConsumerProjectLimit,
    ServiceAttachmentList,
    ServiceAttachmentsScopedList,
    ServiceAttachmentTunnelingConfig,
    SetAutoHealingPoliciesInstanceGroupManagerRequest,
    SetAutoHealingPoliciesRegionInstanceGroupManagerRequest,
    SetBackendServiceTargetSslProxyRequest,
    SetBackendServiceTargetTcpProxyRequest,
    SetBackupTargetPoolRequest,
    SetCertificateMapTargetHttpsProxyRequest,
    SetCertificateMapTargetSslProxyRequest,
    SetCloudArmorTierProjectRequest,
    SetCommonInstanceMetadataOperationMetadata,
    SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo,
    SetCommonInstanceMetadataProjectRequest,
    SetDefaultNetworkTierProjectRequest,
    SetDeletionProtectionInstanceRequest,
    SetDiskAutoDeleteInstanceRequest,
    SetEdgeSecurityPolicyBackendBucketRequest,
    SetEdgeSecurityPolicyBackendServiceRequest,
    SetIamPolicyBackendBucketRequest,
    SetIamPolicyBackendServiceRequest,
    SetIamPolicyDiskRequest,
    SetIamPolicyFirewallPolicyRequest,
    SetIamPolicyImageRequest,
    SetIamPolicyInstanceRequest,
    SetIamPolicyInstanceTemplateRequest,
    SetIamPolicyInstantSnapshotRequest,
    SetIamPolicyInterconnectAttachmentGroupRequest,
    SetIamPolicyInterconnectGroupRequest,
    SetIamPolicyLicenseRequest,
    SetIamPolicyMachineImageRequest,
    SetIamPolicyNetworkAttachmentRequest,
    SetIamPolicyNetworkFirewallPolicyRequest,
    SetIamPolicyNodeGroupRequest,
    SetIamPolicyNodeTemplateRequest,
    SetIamPolicyRegionBackendServiceRequest,
    SetIamPolicyRegionDiskRequest,
    SetIamPolicyRegionInstantSnapshotRequest,
    SetIamPolicyRegionNetworkFirewallPolicyRequest,
    SetIamPolicyRegionSnapshotRequest,
    SetIamPolicyReservationRequest,
    SetIamPolicyResourcePolicyRequest,
    SetIamPolicyServiceAttachmentRequest,
    SetIamPolicySnapshotRequest,
    SetIamPolicyStoragePoolRequest,
    SetIamPolicySubnetworkRequest,
    SetInstanceTemplateInstanceGroupManagerRequest,
    SetInstanceTemplateRegionInstanceGroupManagerRequest,
    SetLabelsAddressRequest,
    SetLabelsDiskRequest,
    SetLabelsExternalVpnGatewayRequest,
    SetLabelsForwardingRuleRequest,
    SetLabelsGlobalAddressRequest,
    SetLabelsGlobalForwardingRuleRequest,
    SetLabelsImageRequest,
    SetLabelsInstanceRequest,
    SetLabelsInstantSnapshotRequest,
    SetLabelsInterconnectAttachmentRequest,
    SetLabelsInterconnectRequest,
    SetLabelsMachineImageRequest,
    SetLabelsRegionDiskRequest,
    SetLabelsRegionInstantSnapshotRequest,
    SetLabelsRegionSecurityPolicyRequest,
    SetLabelsRegionSnapshotRequest,
    SetLabelsSecurityPolicyRequest,
    SetLabelsSnapshotRequest,
    SetLabelsTargetVpnGatewayRequest,
    SetLabelsVpnGatewayRequest,
    SetLabelsVpnTunnelRequest,
    SetMachineResourcesInstanceRequest,
    SetMachineTypeInstanceRequest,
    SetManagedProtectionTierProjectRequest,
    SetMetadataInstanceRequest,
    SetMinCpuPlatformInstanceRequest,
    SetNamedPortsInstanceGroupRequest,
    SetNamedPortsRegionInstanceGroupRequest,
    SetNameInstanceRequest,
    SetNodeTemplateNodeGroupRequest,
    SetPrivateIpGoogleAccessSubnetworkRequest,
    SetProxyHeaderTargetSslProxyRequest,
    SetProxyHeaderTargetTcpProxyRequest,
    SetQuicOverrideTargetHttpsProxyRequest,
    SetSchedulingInstanceRequest,
    SetSecurityPolicyBackendServiceRequest,
    SetSecurityPolicyInstanceRequest,
    SetSecurityPolicyRegionBackendServiceRequest,
    SetSecurityPolicyTargetInstanceRequest,
    SetSecurityPolicyTargetPoolRequest,
    SetServiceAccountInstanceRequest,
    SetShieldedInstanceIntegrityPolicyInstanceRequest,
    SetShieldedVmIntegrityPolicyInstanceRequest,
    SetSslCertificatesRegionTargetHttpsProxyRequest,
    SetSslCertificatesTargetHttpsProxyRequest,
    SetSslCertificatesTargetSslProxyRequest,
    SetSslPolicyTargetHttpsProxyRequest,
    SetSslPolicyTargetSslProxyRequest,
    SetTagsInstanceRequest,
    SetTargetForwardingRuleRequest,
    SetTargetGlobalForwardingRuleRequest,
    SetTargetPoolsInstanceGroupManagerRequest,
    SetTargetPoolsRegionInstanceGroupManagerRequest,
    SetUrlMapRegionTargetHttpProxyRequest,
    SetUrlMapRegionTargetHttpsProxyRequest,
    SetUrlMapTargetHttpProxyRequest,
    SetUrlMapTargetHttpsProxyRequest,
    SetUsageExportBucketProjectRequest,
    ShareSettings,
    ShareSettingsProjectConfig,
    ShieldedInstanceConfig,
    ShieldedInstanceIdentity,
    ShieldedInstanceIdentityEntry,
    ShieldedInstanceIntegrityPolicy,
    ShieldedVmConfig,
    ShieldedVmIdentity,
    ShieldedVmIdentityEntry,
    ShieldedVmIntegrityPolicy,
    SignedUrlKey,
    SimulateMaintenanceEventInstanceRequest,
    SimulateMaintenanceEventNodeGroupRequest,
    Snapshot,
    SnapshotAggregatedList,
    SnapshotList,
    SnapshotSettings,
    SnapshotSettingsAccessLocation,
    SnapshotSettingsAccessLocationAccessLocationPreference,
    SnapshotSettingsStorageLocationSettings,
    SnapshotSettingsStorageLocationSettingsStorageLocationPreference,
    SnapshotsScopedList,
    SourceDiskEncryptionKey,
    SourceInstanceParams,
    SourceInstanceProperties,
    SslCertificate,
    SslCertificateAggregatedList,
    SslCertificateList,
    SslCertificateManagedSslCertificate,
    SslCertificateSelfManagedSslCertificate,
    SslCertificatesScopedList,
    SSLHealthCheck,
    SslPoliciesAggregatedList,
    SslPoliciesList,
    SslPoliciesListAvailableFeaturesResponse,
    SslPoliciesScopedList,
    SslPolicy,
    SslPolicyReference,
    StartAsyncReplicationDiskRequest,
    StartAsyncReplicationRegionDiskRequest,
    StartInstanceRequest,
    StartInstancesInstanceGroupManagerRequest,
    StartInstancesRegionInstanceGroupManagerRequest,
    StartWithEncryptionKeyInstanceRequest,
    StatefulPolicy,
    StatefulPolicyPreservedState,
    StatefulPolicyPreservedStateDiskDevice,
    StatefulPolicyPreservedStateNetworkIp,
    Status,
    StopAsyncReplicationDiskRequest,
    StopAsyncReplicationRegionDiskRequest,
    StopGroupAsyncReplicationDiskRequest,
    StopGroupAsyncReplicationRegionDiskRequest,
    StopInstanceRequest,
    StopInstancesInstanceGroupManagerRequest,
    StopInstancesRegionInstanceGroupManagerRequest,
    StoragePool,
    StoragePoolAggregatedList,
    StoragePoolDisk,
    StoragePoolList,
    StoragePoolListDisks,
    StoragePoolResourceStatus,
    StoragePoolsScopedList,
    StoragePoolType,
    StoragePoolTypeAggregatedList,
    StoragePoolTypeList,
    StoragePoolTypesScopedList,
    StructuredEntries,
    Subnetwork,
    SubnetworkAggregatedList,
    SubnetworkList,
    SubnetworkLogConfig,
    SubnetworkParams,
    SubnetworkSecondaryRange,
    SubnetworksExpandIpCidrRangeRequest,
    SubnetworksScopedList,
    SubnetworksScopedWarning,
    SubnetworksSetPrivateIpGoogleAccessRequest,
    Subsetting,
    SuspendInstanceRequest,
    SuspendInstancesInstanceGroupManagerRequest,
    SuspendInstancesRegionInstanceGroupManagerRequest,
    SwitchToCustomModeNetworkRequest,
    Tags,
    TargetGrpcProxy,
    TargetGrpcProxyList,
    TargetHttpProxiesScopedList,
    TargetHttpProxy,
    TargetHttpProxyAggregatedList,
    TargetHttpProxyList,
    TargetHttpsProxiesScopedList,
    TargetHttpsProxiesSetCertificateMapRequest,
    TargetHttpsProxiesSetQuicOverrideRequest,
    TargetHttpsProxiesSetSslCertificatesRequest,
    TargetHttpsProxy,
    TargetHttpsProxyAggregatedList,
    TargetHttpsProxyList,
    TargetInstance,
    TargetInstanceAggregatedList,
    TargetInstanceList,
    TargetInstancesScopedList,
    TargetPool,
    TargetPoolAggregatedList,
    TargetPoolInstanceHealth,
    TargetPoolList,
    TargetPoolsAddHealthCheckRequest,
    TargetPoolsAddInstanceRequest,
    TargetPoolsRemoveHealthCheckRequest,
    TargetPoolsRemoveInstanceRequest,
    TargetPoolsScopedList,
    TargetReference,
    TargetSslProxiesSetBackendServiceRequest,
    TargetSslProxiesSetCertificateMapRequest,
    TargetSslProxiesSetProxyHeaderRequest,
    TargetSslProxiesSetSslCertificatesRequest,
    TargetSslProxy,
    TargetSslProxyList,
    TargetTcpProxiesScopedList,
    TargetTcpProxiesSetBackendServiceRequest,
    TargetTcpProxiesSetProxyHeaderRequest,
    TargetTcpProxy,
    TargetTcpProxyAggregatedList,
    TargetTcpProxyList,
    TargetVpnGateway,
    TargetVpnGatewayAggregatedList,
    TargetVpnGatewayList,
    TargetVpnGatewaysScopedList,
    TCPHealthCheck,
    TestFailure,
    TestIamPermissionsAddressRequest,
    TestIamPermissionsAutoscalerRequest,
    TestIamPermissionsBackendBucketRequest,
    TestIamPermissionsBackendServiceRequest,
    TestIamPermissionsDiskRequest,
    TestIamPermissionsExternalVpnGatewayRequest,
    TestIamPermissionsFirewallPolicyRequest,
    TestIamPermissionsFirewallRequest,
    TestIamPermissionsForwardingRuleRequest,
    TestIamPermissionsGlobalAddressRequest,
    TestIamPermissionsGlobalForwardingRuleRequest,
    TestIamPermissionsHealthCheckRequest,
    TestIamPermissionsImageRequest,
    TestIamPermissionsInstanceGroupManagerRequest,
    TestIamPermissionsInstanceGroupRequest,
    TestIamPermissionsInstanceRequest,
    TestIamPermissionsInstanceTemplateRequest,
    TestIamPermissionsInstantSnapshotRequest,
    TestIamPermissionsInterconnectAttachmentGroupRequest,
    TestIamPermissionsInterconnectAttachmentRequest,
    TestIamPermissionsInterconnectGroupRequest,
    TestIamPermissionsInterconnectRequest,
    TestIamPermissionsLicenseCodeRequest,
    TestIamPermissionsLicenseRequest,
    TestIamPermissionsMachineImageRequest,
    TestIamPermissionsNetworkAttachmentRequest,
    TestIamPermissionsNetworkEndpointGroupRequest,
    TestIamPermissionsNetworkFirewallPolicyRequest,
    TestIamPermissionsNetworkRequest,
    TestIamPermissionsNodeGroupRequest,
    TestIamPermissionsNodeTemplateRequest,
    TestIamPermissionsPacketMirroringRequest,
    TestIamPermissionsRegionAutoscalerRequest,
    TestIamPermissionsRegionBackendServiceRequest,
    TestIamPermissionsRegionCommitmentRequest,
    TestIamPermissionsRegionDiskRequest,
    TestIamPermissionsRegionHealthCheckRequest,
    TestIamPermissionsRegionHealthCheckServiceRequest,
    TestIamPermissionsRegionInstanceGroupManagerRequest,
    TestIamPermissionsRegionInstanceGroupRequest,
    TestIamPermissionsRegionInstantSnapshotRequest,
    TestIamPermissionsRegionNetworkFirewallPolicyRequest,
    TestIamPermissionsRegionNotificationEndpointRequest,
    TestIamPermissionsRegionSnapshotRequest,
    TestIamPermissionsRegionSslCertificateRequest,
    TestIamPermissionsRegionSslPolicyRequest,
    TestIamPermissionsRegionTargetHttpProxyRequest,
    TestIamPermissionsRegionTargetHttpsProxyRequest,
    TestIamPermissionsRegionTargetTcpProxyRequest,
    TestIamPermissionsRegionUrlMapRequest,
    TestIamPermissionsReservationRequest,
    TestIamPermissionsResourcePolicyRequest,
    TestIamPermissionsRouteRequest,
    TestIamPermissionsRouterRequest,
    TestIamPermissionsSecurityPolicyRequest,
    TestIamPermissionsServiceAttachmentRequest,
    TestIamPermissionsSnapshotRequest,
    TestIamPermissionsSslCertificateRequest,
    TestIamPermissionsSslPolicyRequest,
    TestIamPermissionsStoragePoolRequest,
    TestIamPermissionsSubnetworkRequest,
    TestIamPermissionsTargetGrpcProxyRequest,
    TestIamPermissionsTargetHttpProxyRequest,
    TestIamPermissionsTargetHttpsProxyRequest,
    TestIamPermissionsTargetInstanceRequest,
    TestIamPermissionsTargetPoolRequest,
    TestIamPermissionsTargetSslProxyRequest,
    TestIamPermissionsTargetTcpProxyRequest,
    TestIamPermissionsTargetVpnGatewayRequest,
    TestIamPermissionsUrlMapRequest,
    TestIamPermissionsVpnGatewayRequest,
    TestIamPermissionsVpnTunnelRequest,
    TestPermissionsRequest,
    TestPermissionsResponse,
    Uint128,
    UpcomingMaintenance,
    UpdateAccessConfigInstanceRequest,
    UpdateAutoscalerRequest,
    UpdateBackendBucketRequest,
    UpdateBackendServiceRequest,
    UpdateDiskRequest,
    UpdateDisplayDeviceInstanceRequest,
    UpdateFirewallRequest,
    UpdateFutureReservationRequest,
    UpdateHealthCheckRequest,
    UpdateInstanceGroupManagerRequest,
    UpdateInstanceRequest,
    UpdateLicenseRequest,
    UpdateNetworkInterfaceInstanceRequest,
    UpdatePeeringNetworkRequest,
    UpdatePerInstanceConfigsInstanceGroupManagerRequest,
    UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest,
    UpdatePreviewFeatureRequest,
    UpdateRegionAutoscalerRequest,
    UpdateRegionBackendServiceRequest,
    UpdateRegionCommitmentRequest,
    UpdateRegionDiskRequest,
    UpdateRegionHealthCheckRequest,
    UpdateRegionInstanceGroupManagerRequest,
    UpdateRegionUrlMapRequest,
    UpdateReservationRequest,
    UpdateReservationsRegionCommitmentRequest,
    UpdateRoutePolicyRouterRequest,
    UpdateRouterRequest,
    UpdateShieldedInstanceConfigInstanceRequest,
    UpdateShieldedVmConfigInstanceRequest,
    UpdateStoragePoolRequest,
    UpdateUrlMapRequest,
    UrlMap,
    UrlMapList,
    UrlMapReference,
    UrlMapsAggregatedList,
    UrlMapsScopedList,
    UrlMapsValidateRequest,
    UrlMapsValidateResponse,
    UrlMapTest,
    UrlMapTestHeader,
    UrlMapValidationResult,
    UrlRewrite,
    UsableSubnetwork,
    UsableSubnetworksAggregatedList,
    UsableSubnetworkSecondaryRange,
    UsageExportLocation,
    ValidateRegionUrlMapRequest,
    ValidateUrlMapRequest,
    VmEndpointNatMappings,
    VmEndpointNatMappingsInterfaceNatMappings,
    VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings,
    VmEndpointNatMappingsList,
    VpnGateway,
    VpnGatewayAggregatedList,
    VpnGatewayList,
    VpnGatewaysGetStatusResponse,
    VpnGatewaysScopedList,
    VpnGatewayStatus,
    VpnGatewayStatusHighAvailabilityRequirementState,
    VpnGatewayStatusTunnel,
    VpnGatewayStatusVpnConnection,
    VpnGatewayVpnGatewayInterface,
    VpnTunnel,
    VpnTunnelAggregatedList,
    VpnTunnelList,
    VpnTunnelsScopedList,
    WafExpressionSet,
    WafExpressionSetExpression,
    WaitGlobalOperationRequest,
    WaitRegionOperationRequest,
    WaitZoneOperationRequest,
    Warning,
    Warnings,
    WeightedBackendService,
    Wire,
    WireEndpoint,
    WireGroup,
    WireGroupEndpoint,
    WireGroupEndpointInterconnect,
    WireGroupList,
    WireGroupProperties,
    WireGroupTopology,
    WireGroupTopologyEndpoint,
    WireProperties,
    WithdrawPublicAdvertisedPrefixeRequest,
    WithdrawPublicDelegatedPrefixeRequest,
    XpnHostList,
    XpnResourceId,
    Zone,
    ZoneList,
    ZoneSetLabelsRequest,
    ZoneSetPolicyRequest,
)

__all__ = (
    "AbandonInstancesInstanceGroupManagerRequest",
    "AbandonInstancesRegionInstanceGroupManagerRequest",
    "AcceleratorConfig",
    "Accelerators",
    "AcceleratorType",
    "AcceleratorTypeAggregatedList",
    "AcceleratorTypeList",
    "AcceleratorTypesScopedList",
    "AccessConfig",
    "AddAccessConfigInstanceRequest",
    "AddAssociationFirewallPolicyRequest",
    "AddAssociationNetworkFirewallPolicyRequest",
    "AddAssociationOrganizationSecurityPolicyRequest",
    "AddAssociationRegionNetworkFirewallPolicyRequest",
    "AddHealthCheckTargetPoolRequest",
    "AddInstancesInstanceGroupRequest",
    "AddInstanceTargetPoolRequest",
    "AddNetworkInterfaceInstanceRequest",
    "AddNodesNodeGroupRequest",
    "AddPacketMirroringRuleFirewallPolicyRequest",
    "AddPacketMirroringRuleNetworkFirewallPolicyRequest",
    "AddPeeringNetworkRequest",
    "AddResourcePoliciesDiskRequest",
    "AddResourcePoliciesInstanceRequest",
    "AddResourcePoliciesRegionDiskRequest",
    "Address",
    "AddressAggregatedList",
    "AddressesScopedList",
    "AddressList",
    "AddRuleFirewallPolicyRequest",
    "AddRuleNetworkFirewallPolicyRequest",
    "AddRuleOrganizationSecurityPolicyRequest",
    "AddRuleRegionNetworkFirewallPolicyRequest",
    "AddRuleRegionSecurityPolicyRequest",
    "AddRuleSecurityPolicyRequest",
    "AddSignedUrlKeyBackendBucketRequest",
    "AddSignedUrlKeyBackendServiceRequest",
    "AdvancedMachineFeatures",
    "AggregatedListAcceleratorTypesRequest",
    "AggregatedListAddressesRequest",
    "AggregatedListAutoscalersRequest",
    "AggregatedListBackendServicesRequest",
    "AggregatedListDisksRequest",
    "AggregatedListDiskTypesRequest",
    "AggregatedListForwardingRulesRequest",
    "AggregatedListFutureReservationsRequest",
    "AggregatedListGlobalOperationsRequest",
    "AggregatedListHealthChecksRequest",
    "AggregatedListInstanceGroupManagersRequest",
    "AggregatedListInstanceGroupsRequest",
    "AggregatedListInstancesRequest",
    "AggregatedListInstanceTemplatesRequest",
    "AggregatedListInstantSnapshotsRequest",
    "AggregatedListInterconnectAttachmentsRequest",
    "AggregatedListMachineTypesRequest",
    "AggregatedListNetworkAttachmentsRequest",
    "AggregatedListNetworkEdgeSecurityServicesRequest",
    "AggregatedListNetworkEndpointGroupsRequest",
    "AggregatedListNetworkFirewallPoliciesRequest",
    "AggregatedListNodeGroupsRequest",
    "AggregatedListNodeTemplatesRequest",
    "AggregatedListNodeTypesRequest",
    "AggregatedListPacketMirroringsRequest",
    "AggregatedListPublicDelegatedPrefixesRequest",
    "AggregatedListRegionCommitmentsRequest",
    "AggregatedListReservationsRequest",
    "AggregatedListResourcePoliciesRequest",
    "AggregatedListRoutersRequest",
    "AggregatedListSecurityPoliciesRequest",
    "AggregatedListServiceAttachmentsRequest",
    "AggregatedListSnapshotsRequest",
    "AggregatedListSslCertificatesRequest",
    "AggregatedListSslPoliciesRequest",
    "AggregatedListStoragePoolsRequest",
    "AggregatedListStoragePoolTypesRequest",
    "AggregatedListSubnetworksRequest",
    "AggregatedListTargetHttpProxiesRequest",
    "AggregatedListTargetHttpsProxiesRequest",
    "AggregatedListTargetInstancesRequest",
    "AggregatedListTargetPoolsRequest",
    "AggregatedListTargetTcpProxiesRequest",
    "AggregatedListTargetVpnGatewaysRequest",
    "AggregatedListUrlMapsRequest",
    "AggregatedListVpnGatewaysRequest",
    "AggregatedListVpnTunnelsRequest",
    "AliasIpRange",
    "AllocationAggregateReservation",
    "AllocationAggregateReservationReservedResourceInfo",
    "AllocationAggregateReservationReservedResourceInfoAccelerator",
    "AllocationReservationSharingPolicy",
    "AllocationResourceStatus",
    "AllocationResourceStatusSpecificSKUAllocation",
    "AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk",
    "AllocationSpecificSKUAllocationReservedInstanceProperties",
    "AllocationSpecificSKUReservation",
    "Allowed",
    "AnnouncePublicAdvertisedPrefixeRequest",
    "AnnouncePublicDelegatedPrefixeRequest",
    "ApplyUpdatesToInstancesInstanceGroupManagerRequest",
    "ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest",
    "AttachDiskInstanceRequest",
    "AttachedDisk",
    "AttachedDiskInitializeParams",
    "AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest",
    "AttachNetworkEndpointsNetworkEndpointGroupRequest",
    "AttachNetworkEndpointsRegionNetworkEndpointGroupRequest",
    "AuditConfig",
    "AuditLogConfig",
    "Autoscaler",
    "AutoscalerAggregatedList",
    "AutoscalerList",
    "AutoscalersScopedList",
    "AutoscalerStatusDetails",
    "AutoscalingPolicy",
    "AutoscalingPolicyCpuUtilization",
    "AutoscalingPolicyCustomMetricUtilization",
    "AutoscalingPolicyLoadBalancingUtilization",
    "AutoscalingPolicyScaleDownControl",
    "AutoscalingPolicyScaleInControl",
    "AutoscalingPolicyScalingSchedule",
    "AWSV4Signature",
    "Backend",
    "BackendBucket",
    "BackendBucketCdnPolicy",
    "BackendBucketCdnPolicyBypassCacheOnRequestHeader",
    "BackendBucketCdnPolicyCacheKeyPolicy",
    "BackendBucketCdnPolicyNegativeCachingPolicy",
    "BackendBucketList",
    "BackendBucketListUsable",
    "BackendBucketUsedBy",
    "BackendCustomMetric",
    "BackendService",
    "BackendServiceAggregatedList",
    "BackendServiceCdnPolicy",
    "BackendServiceCdnPolicyBypassCacheOnRequestHeader",
    "BackendServiceCdnPolicyNegativeCachingPolicy",
    "BackendServiceConnectionTrackingPolicy",
    "BackendServiceCustomMetric",
    "BackendServiceDynamicForwarding",
    "BackendServiceDynamicForwardingIpPortSelection",
    "BackendServiceFailoverPolicy",
    "BackendServiceGroupHealth",
    "BackendServiceHAPolicy",
    "BackendServiceHAPolicyLeader",
    "BackendServiceHAPolicyLeaderNetworkEndpoint",
    "BackendServiceHttpCookie",
    "BackendServiceIAP",
    "BackendServiceList",
    "BackendServiceListUsable",
    "BackendServiceLocalityLoadBalancingPolicyConfig",
    "BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy",
    "BackendServiceLocalityLoadBalancingPolicyConfigPolicy",
    "BackendServiceLogConfig",
    "BackendServiceNetworkPassThroughLbTrafficPolicy",
    "BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity",
    "BackendServiceReference",
    "BackendServicesGetEffectiveSecurityPoliciesResponse",
    "BackendServicesScopedList",
    "BackendServiceTlsSettings",
    "BackendServiceTlsSettingsSubjectAltName",
    "BackendServiceUsedBy",
    "BfdPacket",
    "BfdStatus",
    "BfdStatusPacketCounts",
    "BgpRoute",
    "BgpRouteAsPath",
    "BgpRouteNetworkLayerReachabilityInformation",
    "Binding",
    "BulkInsertDiskRequest",
    "BulkInsertDiskResource",
    "BulkInsertInstanceRequest",
    "BulkInsertInstanceResource",
    "BulkInsertInstanceResourcePerInstanceProperties",
    "BulkInsertOperationStatus",
    "BulkInsertRegionDiskRequest",
    "BulkInsertRegionInstanceRequest",
    "BulkSetLabelsDiskRequest",
    "BulkSetLabelsRequest",
    "BulkZoneSetLabelsRequest",
    "BundledLocalSsds",
    "CacheInvalidationRule",
    "CacheKeyPolicy",
    "CalendarModeAdviceRequest",
    "CalendarModeAdviceResponse",
    "CalendarModeAdviceRpcRequest",
    "CalendarModeRecommendation",
    "CancelFutureReservationRequest",
    "CancelInstanceGroupManagerResizeRequestRequest",
    "CancelRegionInstanceGroupManagerResizeRequestRequest",
    "CircuitBreakers",
    "CloneRulesFirewallPolicyRequest",
    "CloneRulesNetworkFirewallPolicyRequest",
    "CloneRulesRegionNetworkFirewallPolicyRequest",
    "Commitment",
    "CommitmentAggregatedList",
    "CommitmentList",
    "CommitmentResourceStatus",
    "CommitmentsScopedList",
    "ConfidentialInstanceConfig",
    "ConnectionDraining",
    "ConsistentHashLoadBalancerSettings",
    "ConsistentHashLoadBalancerSettingsHttpCookie",
    "CopyRulesOrganizationSecurityPolicyRequest",
    "CorsPolicy",
    "CreateInstancesInstanceGroupManagerRequest",
    "CreateInstancesRegionInstanceGroupManagerRequest",
    "CreateMembersInterconnectGroupRequest",
    "CreateSnapshotDiskRequest",
    "CreateSnapshotRegionDiskRequest",
    "CrossSiteNetwork",
    "CrossSiteNetworkList",
    "CustomerEncryptionKey",
    "CustomerEncryptionKeyProtectedDisk",
    "CustomErrorResponsePolicy",
    "CustomErrorResponsePolicyCustomErrorResponseRule",
    "Data",
    "Date",
    "DeleteAccessConfigInstanceRequest",
    "DeleteAddressRequest",
    "DeleteAutoscalerRequest",
    "DeleteBackendBucketRequest",
    "DeleteBackendServiceRequest",
    "DeleteCrossSiteNetworkRequest",
    "DeleteDiskRequest",
    "DeleteExternalVpnGatewayRequest",
    "DeleteFirewallPolicyRequest",
    "DeleteFirewallRequest",
    "DeleteForwardingRuleRequest",
    "DeleteFutureReservationRequest",
    "DeleteGlobalAddressRequest",
    "DeleteGlobalForwardingRuleRequest",
    "DeleteGlobalNetworkEndpointGroupRequest",
    "DeleteGlobalOperationRequest",
    "DeleteGlobalOperationResponse",
    "DeleteGlobalOrganizationOperationRequest",
    "DeleteGlobalOrganizationOperationResponse",
    "DeleteGlobalPublicDelegatedPrefixeRequest",
    "DeleteHealthCheckRequest",
    "DeleteImageRequest",
    "DeleteInstanceGroupManagerRequest",
    "DeleteInstanceGroupManagerResizeRequestRequest",
    "DeleteInstanceGroupRequest",
    "DeleteInstanceRequest",
    "DeleteInstancesInstanceGroupManagerRequest",
    "DeleteInstancesRegionInstanceGroupManagerRequest",
    "DeleteInstanceTemplateRequest",
    "DeleteInstantSnapshotRequest",
    "DeleteInterconnectAttachmentGroupRequest",
    "DeleteInterconnectAttachmentRequest",
    "DeleteInterconnectGroupRequest",
    "DeleteInterconnectRequest",
    "DeleteLicenseRequest",
    "DeleteMachineImageRequest",
    "DeleteNetworkAttachmentRequest",
    "DeleteNetworkEdgeSecurityServiceRequest",
    "DeleteNetworkEndpointGroupRequest",
    "DeleteNetworkFirewallPolicyRequest",
    "DeleteNetworkInterfaceInstanceRequest",
    "DeleteNetworkRequest",
    "DeleteNodeGroupRequest",
    "DeleteNodesNodeGroupRequest",
    "DeleteNodeTemplateRequest",
    "DeleteOrganizationSecurityPolicyRequest",
    "DeletePacketMirroringRequest",
    "DeletePerInstanceConfigsInstanceGroupManagerRequest",
    "DeletePerInstanceConfigsRegionInstanceGroupManagerRequest",
    "DeletePublicAdvertisedPrefixeRequest",
    "DeletePublicDelegatedPrefixeRequest",
    "DeleteRegionAutoscalerRequest",
    "DeleteRegionBackendServiceRequest",
    "DeleteRegionDiskRequest",
    "DeleteRegionHealthCheckRequest",
    "DeleteRegionHealthCheckServiceRequest",
    "DeleteRegionInstanceGroupManagerRequest",
    "DeleteRegionInstanceGroupManagerResizeRequestRequest",
    "DeleteRegionInstanceTemplateRequest",
    "DeleteRegionInstantSnapshotRequest",
    "DeleteRegionMultiMigRequest",
    "DeleteRegionNetworkEndpointGroupRequest",
    "DeleteRegionNetworkFirewallPolicyRequest",
    "DeleteRegionNotificationEndpointRequest",
    "DeleteRegionOperationRequest",
    "DeleteRegionOperationResponse",
    "DeleteRegionSecurityPolicyRequest",
    "DeleteRegionSnapshotRequest",
    "DeleteRegionSslCertificateRequest",
    "DeleteRegionSslPolicyRequest",
    "DeleteRegionTargetHttpProxyRequest",
    "DeleteRegionTargetHttpsProxyRequest",
    "DeleteRegionTargetTcpProxyRequest",
    "DeleteRegionUrlMapRequest",
    "DeleteReservationRequest",
    "DeleteResourcePolicyRequest",
    "DeleteRoutePolicyRouterRequest",
    "DeleteRouteRequest",
    "DeleteRouterRequest",
    "DeleteSecurityPolicyRequest",
    "DeleteServiceAttachmentRequest",
    "DeleteSignedUrlKeyBackendBucketRequest",
    "DeleteSignedUrlKeyBackendServiceRequest",
    "DeleteSnapshotRequest",
    "DeleteSslCertificateRequest",
    "DeleteSslPolicyRequest",
    "DeleteStoragePoolRequest",
    "DeleteSubnetworkRequest",
    "DeleteTargetGrpcProxyRequest",
    "DeleteTargetHttpProxyRequest",
    "DeleteTargetHttpsProxyRequest",
    "DeleteTargetInstanceRequest",
    "DeleteTargetPoolRequest",
    "DeleteTargetSslProxyRequest",
    "DeleteTargetTcpProxyRequest",
    "DeleteTargetVpnGatewayRequest",
    "DeleteUrlMapRequest",
    "DeleteVpnGatewayRequest",
    "DeleteVpnTunnelRequest",
    "DeleteWireGroupRequest",
    "DeleteZoneOperationRequest",
    "DeleteZoneOperationResponse",
    "Denied",
    "DeprecateImageRequest",
    "DeprecationStatus",
    "DetachDiskInstanceRequest",
    "DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest",
    "DetachNetworkEndpointsNetworkEndpointGroupRequest",
    "DetachNetworkEndpointsRegionNetworkEndpointGroupRequest",
    "DisableXpnHostProjectRequest",
    "DisableXpnResourceProjectRequest",
    "Disk",
    "DiskAggregatedList",
    "DiskAsyncReplication",
    "DiskAsyncReplicationList",
    "DiskInstantiationConfig",
    "DiskList",
    "DiskMoveRequest",
    "DiskParams",
    "DiskResourceStatus",
    "DiskResourceStatusAsyncReplicationStatus",
    "DisksAddResourcePoliciesRequest",
    "DiskSettings",
    "DiskSettingsAccessLocation",
    "DiskSettingsAccessLocationAccessLocationPreference",
    "DisksRemoveResourcePoliciesRequest",
    "DisksResizeRequest",
    "DisksScopedList",
    "DisksStartAsyncReplicationRequest",
    "DisksStopGroupAsyncReplicationResource",
    "DiskType",
    "DiskTypeAggregatedList",
    "DiskTypeList",
    "DiskTypesScopedList",
    "DisplayDevice",
    "DistributionPolicy",
    "DistributionPolicyZoneConfiguration",
    "Duration",
    "EnableXpnHostProjectRequest",
    "EnableXpnResourceProjectRequest",
    "Error",
    "ErrorDetails",
    "ErrorInfo",
    "Errors",
    "ExchangedPeeringRoute",
    "ExchangedPeeringRoutesList",
    "ExpandIpCidrRangeSubnetworkRequest",
    "Expr",
    "ExternalVpnGateway",
    "ExternalVpnGatewayInterface",
    "ExternalVpnGatewayList",
    "FileContentBuffer",
    "Firewall",
    "FirewallList",
    "FirewallLogConfig",
    "FirewallParams",
    "FirewallPoliciesListAssociationsResponse",
    "FirewallPoliciesScopedList",
    "FirewallPolicy",
    "FirewallPolicyAssociation",
    "FirewallPolicyList",
    "FirewallPolicyRule",
    "FirewallPolicyRuleMatcher",
    "FirewallPolicyRuleMatcherLayer4Config",
    "FirewallPolicyRuleSecureTag",
    "FixedOrPercent",
    "FlexibleTimeRange",
    "ForwardingRule",
    "ForwardingRuleAggregatedList",
    "ForwardingRuleList",
    "ForwardingRuleReference",
    "ForwardingRuleServiceDirectoryRegistration",
    "ForwardingRulesScopedList",
    "FutureReservation",
    "FutureReservationCommitmentInfo",
    "FutureReservationsAggregatedListResponse",
    "FutureReservationsListResponse",
    "FutureReservationSpecificSKUProperties",
    "FutureReservationsScopedList",
    "FutureReservationStatus",
    "FutureReservationStatusExistingMatchingUsageInfo",
    "FutureReservationStatusLastKnownGoodState",
    "FutureReservationStatusLastKnownGoodStateFutureReservationSpecs",
    "FutureReservationStatusSpecificSKUProperties",
    "FutureReservationTimeWindow",
    "FutureResourcesRecommendation",
    "FutureResourcesRecommendationOtherLocation",
    "FutureResourcesSpec",
    "FutureResourcesSpecAggregateResources",
    "FutureResourcesSpecLocalSsdPartition",
    "FutureResourcesSpecLocationPolicy",
    "FutureResourcesSpecLocationPolicyLocation",
    "FutureResourcesSpecSpecificSKUResources",
    "FutureResourcesSpecTargetResources",
    "GetAcceleratorTypeRequest",
    "GetAddressRequest",
    "GetAssociationFirewallPolicyRequest",
    "GetAssociationNetworkFirewallPolicyRequest",
    "GetAssociationOrganizationSecurityPolicyRequest",
    "GetAssociationRegionNetworkFirewallPolicyRequest",
    "GetAutoscalerRequest",
    "GetBackendBucketRequest",
    "GetBackendServiceRequest",
    "GetCrossSiteNetworkRequest",
    "GetDiagnosticsInterconnectRequest",
    "GetDiskRequest",
    "GetDiskSettingRequest",
    "GetDiskTypeRequest",
    "GetEffectiveFirewallsInstanceRequest",
    "GetEffectiveFirewallsNetworkRequest",
    "GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest",
    "GetEffectiveSecurityPoliciesBackendServiceRequest",
    "GetExternalVpnGatewayRequest",
    "GetFirewallPolicyRequest",
    "GetFirewallRequest",
    "GetForwardingRuleRequest",
    "GetFromFamilyImageRequest",
    "GetFutureReservationRequest",
    "GetGlobalAddressRequest",
    "GetGlobalForwardingRuleRequest",
    "GetGlobalNetworkEndpointGroupRequest",
    "GetGlobalOperationRequest",
    "GetGlobalOrganizationOperationRequest",
    "GetGlobalPublicDelegatedPrefixeRequest",
    "GetGuestAttributesInstanceRequest",
    "GetHealthBackendServiceRequest",
    "GetHealthCheckRequest",
    "GetHealthRegionBackendServiceRequest",
    "GetHealthTargetPoolRequest",
    "GetIamPolicyBackendBucketRequest",
    "GetIamPolicyBackendServiceRequest",
    "GetIamPolicyDiskRequest",
    "GetIamPolicyFirewallPolicyRequest",
    "GetIamPolicyImageRequest",
    "GetIamPolicyInstanceRequest",
    "GetIamPolicyInstanceTemplateRequest",
    "GetIamPolicyInstantSnapshotRequest",
    "GetIamPolicyInterconnectAttachmentGroupRequest",
    "GetIamPolicyInterconnectGroupRequest",
    "GetIamPolicyLicenseRequest",
    "GetIamPolicyMachineImageRequest",
    "GetIamPolicyNetworkAttachmentRequest",
    "GetIamPolicyNetworkFirewallPolicyRequest",
    "GetIamPolicyNodeGroupRequest",
    "GetIamPolicyNodeTemplateRequest",
    "GetIamPolicyRegionBackendServiceRequest",
    "GetIamPolicyRegionDiskRequest",
    "GetIamPolicyRegionInstantSnapshotRequest",
    "GetIamPolicyRegionNetworkFirewallPolicyRequest",
    "GetIamPolicyRegionSnapshotRequest",
    "GetIamPolicyReservationRequest",
    "GetIamPolicyResourcePolicyRequest",
    "GetIamPolicyServiceAttachmentRequest",
    "GetIamPolicySnapshotRequest",
    "GetIamPolicyStoragePoolRequest",
    "GetIamPolicySubnetworkRequest",
    "GetImageFamilyViewRequest",
    "GetImageRequest",
    "GetInstanceGroupManagerRequest",
    "GetInstanceGroupManagerResizeRequestRequest",
    "GetInstanceGroupRequest",
    "GetInstanceRequest",
    "GetInstanceSettingRequest",
    "GetInstanceTemplateRequest",
    "GetInstantSnapshotRequest",
    "GetInterconnectAttachmentGroupRequest",
    "GetInterconnectAttachmentRequest",
    "GetInterconnectGroupRequest",
    "GetInterconnectLocationRequest",
    "GetInterconnectRemoteLocationRequest",
    "GetInterconnectRequest",
    "GetLicenseCodeRequest",
    "GetLicenseRequest",
    "GetMachineImageRequest",
    "GetMachineTypeRequest",
    "GetMacsecConfigInterconnectRequest",
    "GetNatIpInfoRouterRequest",
    "GetNatMappingInfoRoutersRequest",
    "GetNetworkAttachmentRequest",
    "GetNetworkEdgeSecurityServiceRequest",
    "GetNetworkEndpointGroupRequest",
    "GetNetworkFirewallPolicyRequest",
    "GetNetworkProfileRequest",
    "GetNetworkRequest",
    "GetNodeGroupRequest",
    "GetNodeTemplateRequest",
    "GetNodeTypeRequest",
    "GetOperationalStatusInterconnectAttachmentGroupRequest",
    "GetOperationalStatusInterconnectGroupRequest",
    "GetOrganizationSecurityPolicyRequest",
    "GetPacketMirroringRequest",
    "GetPacketMirroringRuleFirewallPolicyRequest",
    "GetPacketMirroringRuleNetworkFirewallPolicyRequest",
    "GetPartnerMetadataInstanceRequest",
    "GetPreviewFeatureRequest",
    "GetProjectRequest",
    "GetPublicAdvertisedPrefixeRequest",
    "GetPublicDelegatedPrefixeRequest",
    "GetRegionAutoscalerRequest",
    "GetRegionBackendServiceRequest",
    "GetRegionCommitmentRequest",
    "GetRegionDiskRequest",
    "GetRegionDiskSettingRequest",
    "GetRegionDiskTypeRequest",
    "GetRegionHealthCheckRequest",
    "GetRegionHealthCheckServiceRequest",
    "GetRegionInstanceGroupManagerRequest",
    "GetRegionInstanceGroupManagerResizeRequestRequest",
    "GetRegionInstanceGroupRequest",
    "GetRegionInstanceTemplateRequest",
    "GetRegionInstantSnapshotRequest",
    "GetRegionMultiMigRequest",
    "GetRegionNetworkEndpointGroupRequest",
    "GetRegionNetworkFirewallPolicyRequest",
    "GetRegionNotificationEndpointRequest",
    "GetRegionOperationRequest",
    "GetRegionRequest",
    "GetRegionSecurityPolicyRequest",
    "GetRegionSnapshotRequest",
    "GetRegionSnapshotSettingRequest",
    "GetRegionSslCertificateRequest",
    "GetRegionSslPolicyRequest",
    "GetRegionTargetHttpProxyRequest",
    "GetRegionTargetHttpsProxyRequest",
    "GetRegionTargetTcpProxyRequest",
    "GetRegionUrlMapRequest",
    "GetReservationBlockRequest",
    "GetReservationRequest",
    "GetResourcePolicyRequest",
    "GetRoutePolicyRouterRequest",
    "GetRouteRequest",
    "GetRouterRequest",
    "GetRouterStatusRouterRequest",
    "GetRuleFirewallPolicyRequest",
    "GetRuleNetworkFirewallPolicyRequest",
    "GetRuleOrganizationSecurityPolicyRequest",
    "GetRuleRegionNetworkFirewallPolicyRequest",
    "GetRuleRegionSecurityPolicyRequest",
    "GetRuleSecurityPolicyRequest",
    "GetScreenshotInstanceRequest",
    "GetSecurityPolicyRequest",
    "GetSerialPortOutputInstanceRequest",
    "GetServiceAttachmentRequest",
    "GetShieldedInstanceIdentityInstanceRequest",
    "GetShieldedVmIdentityInstanceRequest",
    "GetSnapshotRequest",
    "GetSnapshotSettingRequest",
    "GetSslCertificateRequest",
    "GetSslPolicyRequest",
    "GetStatusVpnGatewayRequest",
    "GetStoragePoolRequest",
    "GetStoragePoolTypeRequest",
    "GetSubnetworkRequest",
    "GetTargetGrpcProxyRequest",
    "GetTargetHttpProxyRequest",
    "GetTargetHttpsProxyRequest",
    "GetTargetInstanceRequest",
    "GetTargetPoolRequest",
    "GetTargetSslProxyRequest",
    "GetTargetTcpProxyRequest",
    "GetTargetVpnGatewayRequest",
    "GetUrlMapRequest",
    "GetVpnGatewayRequest",
    "GetVpnTunnelRequest",
    "GetWireGroupRequest",
    "GetXpnHostProjectRequest",
    "GetXpnResourcesProjectsRequest",
    "GetZoneOperationRequest",
    "GetZoneRequest",
    "GlobalAddressesMoveRequest",
    "GlobalNetworkEndpointGroupsAttachEndpointsRequest",
    "GlobalNetworkEndpointGroupsDetachEndpointsRequest",
    "GlobalOrganizationSetPolicyRequest",
    "GlobalSetLabelsRequest",
    "GlobalSetPolicyRequest",
    "GroupMaintenanceInfo",
    "GRPCHealthCheck",
    "GRPCTLSHealthCheck",
    "GuestAttributes",
    "GuestAttributesEntry",
    "GuestAttributesValue",
    "GuestOsFeature",
    "HealthCheck",
    "HealthCheckList",
    "HealthCheckLogConfig",
    "HealthCheckReference",
    "HealthChecksAggregatedList",
    "HealthCheckService",
    "HealthCheckServiceReference",
    "HealthCheckServicesList",
    "HealthChecksScopedList",
    "HealthStatus",
    "HealthStatusForNetworkEndpoint",
    "Help",
    "HelpLink",
    "HostRule",
    "HTTP2HealthCheck",
    "HttpFaultAbort",
    "HttpFaultDelay",
    "HttpFaultInjection",
    "HttpFilterConfig",
    "HttpHeaderAction",
    "HttpHeaderMatch",
    "HttpHeaderOption",
    "HTTPHealthCheck",
    "HttpQueryParameterMatch",
    "HttpRedirectAction",
    "HttpRetryPolicy",
    "HttpRouteAction",
    "HttpRouteRule",
    "HttpRouteRuleMatch",
    "HTTPSHealthCheck",
    "Image",
    "ImageFamilyView",
    "ImageList",
    "InitialStateConfig",
    "InsertAddressRequest",
    "InsertAutoscalerRequest",
    "InsertBackendBucketRequest",
    "InsertBackendServiceRequest",
    "InsertCrossSiteNetworkRequest",
    "InsertDiskRequest",
    "InsertExternalVpnGatewayRequest",
    "InsertFirewallPolicyRequest",
    "InsertFirewallRequest",
    "InsertForwardingRuleRequest",
    "InsertFutureReservationRequest",
    "InsertGlobalAddressRequest",
    "InsertGlobalForwardingRuleRequest",
    "InsertGlobalNetworkEndpointGroupRequest",
    "InsertGlobalPublicDelegatedPrefixeRequest",
    "InsertHealthCheckRequest",
    "InsertImageRequest",
    "InsertInstanceGroupManagerRequest",
    "InsertInstanceGroupManagerResizeRequestRequest",
    "InsertInstanceGroupRequest",
    "InsertInstanceRequest",
    "InsertInstanceTemplateRequest",
    "InsertInstantSnapshotRequest",
    "InsertInterconnectAttachmentGroupRequest",
    "InsertInterconnectAttachmentRequest",
    "InsertInterconnectGroupRequest",
    "InsertInterconnectRequest",
    "InsertLicenseRequest",
    "InsertMachineImageRequest",
    "InsertNetworkAttachmentRequest",
    "InsertNetworkEdgeSecurityServiceRequest",
    "InsertNetworkEndpointGroupRequest",
    "InsertNetworkFirewallPolicyRequest",
    "InsertNetworkRequest",
    "InsertNodeGroupRequest",
    "InsertNodeTemplateRequest",
    "InsertOrganizationSecurityPolicyRequest",
    "InsertPacketMirroringRequest",
    "InsertPublicAdvertisedPrefixeRequest",
    "InsertPublicDelegatedPrefixeRequest",
    "InsertRegionAutoscalerRequest",
    "InsertRegionBackendServiceRequest",
    "InsertRegionCommitmentRequest",
    "InsertRegionDiskRequest",
    "InsertRegionHealthCheckRequest",
    "InsertRegionHealthCheckServiceRequest",
    "InsertRegionInstanceGroupManagerRequest",
    "InsertRegionInstanceGroupManagerResizeRequestRequest",
    "InsertRegionInstanceTemplateRequest",
    "InsertRegionInstantSnapshotRequest",
    "InsertRegionMultiMigRequest",
    "InsertRegionNetworkEndpointGroupRequest",
    "InsertRegionNetworkFirewallPolicyRequest",
    "InsertRegionNotificationEndpointRequest",
    "InsertRegionSecurityPolicyRequest",
    "InsertRegionSnapshotRequest",
    "InsertRegionSslCertificateRequest",
    "InsertRegionSslPolicyRequest",
    "InsertRegionTargetHttpProxyRequest",
    "InsertRegionTargetHttpsProxyRequest",
    "InsertRegionTargetTcpProxyRequest",
    "InsertRegionUrlMapRequest",
    "InsertReservationRequest",
    "InsertResourcePolicyRequest",
    "InsertRouteRequest",
    "InsertRouterRequest",
    "InsertSecurityPolicyRequest",
    "InsertServiceAttachmentRequest",
    "InsertSnapshotRequest",
    "InsertSslCertificateRequest",
    "InsertSslPolicyRequest",
    "InsertStoragePoolRequest",
    "InsertSubnetworkRequest",
    "InsertTargetGrpcProxyRequest",
    "InsertTargetHttpProxyRequest",
    "InsertTargetHttpsProxyRequest",
    "InsertTargetInstanceRequest",
    "InsertTargetPoolRequest",
    "InsertTargetSslProxyRequest",
    "InsertTargetTcpProxyRequest",
    "InsertTargetVpnGatewayRequest",
    "InsertUrlMapRequest",
    "InsertVpnGatewayRequest",
    "InsertVpnTunnelRequest",
    "InsertWireGroupRequest",
    "Instance",
    "InstanceAggregatedList",
    "InstanceConsumptionData",
    "InstanceConsumptionInfo",
    "InstanceGroup",
    "InstanceGroupAggregatedList",
    "InstanceGroupList",
    "InstanceGroupManager",
    "InstanceGroupManagerActionsSummary",
    "InstanceGroupManagerAggregatedList",
    "InstanceGroupManagerAllInstancesConfig",
    "InstanceGroupManagerAutoHealingPolicy",
    "InstanceGroupManagerInstanceFlexibilityPolicy",
    "InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection",
    "InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix",
    "InstanceGroupManagerInstanceLifecyclePolicy",
    "InstanceGroupManagerList",
    "InstanceGroupManagerParams",
    "InstanceGroupManagerResizeRequest",
    "InstanceGroupManagerResizeRequestsListResponse",
    "InstanceGroupManagerResizeRequestStatus",
    "InstanceGroupManagerResizeRequestStatusLastAttempt",
    "InstanceGroupManagerResourcePolicies",
    "InstanceGroupManagersAbandonInstancesRequest",
    "InstanceGroupManagersApplyUpdatesRequest",
    "InstanceGroupManagersCreateInstancesRequest",
    "InstanceGroupManagersDeleteInstancesRequest",
    "InstanceGroupManagersDeletePerInstanceConfigsReq",
    "InstanceGroupManagersListErrorsResponse",
    "InstanceGroupManagersListManagedInstancesResponse",
    "InstanceGroupManagersListPerInstanceConfigsResp",
    "InstanceGroupManagersPatchPerInstanceConfigsReq",
    "InstanceGroupManagersRecreateInstancesRequest",
    "InstanceGroupManagersResizeAdvancedRequest",
    "InstanceGroupManagersResumeInstancesRequest",
    "InstanceGroupManagersScopedList",
    "InstanceGroupManagersSetAutoHealingRequest",
    "InstanceGroupManagersSetInstanceTemplateRequest",
    "InstanceGroupManagersSetTargetPoolsRequest",
    "InstanceGroupManagersStartInstancesRequest",
    "InstanceGroupManagersStopInstancesRequest",
    "InstanceGroupManagersSuspendInstancesRequest",
    "InstanceGroupManagerStandbyPolicy",
    "InstanceGroupManagerStatus",
    "InstanceGroupManagerStatusAllInstancesConfig",
    "InstanceGroupManagerStatusBulkInstanceOperation",
    "InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck",
    "InstanceGroupManagerStatusStateful",
    "InstanceGroupManagerStatusStatefulPerInstanceConfigs",
    "InstanceGroupManagerStatusVersionTarget",
    "InstanceGroupManagersUpdatePerInstanceConfigsReq",
    "InstanceGroupManagerTargetSizePolicy",
    "InstanceGroupManagerUpdatePolicy",
    "InstanceGroupManagerVersion",
    "InstanceGroupsAddInstancesRequest",
    "InstanceGroupsListInstances",
    "InstanceGroupsListInstancesRequest",
    "InstanceGroupsRemoveInstancesRequest",
    "InstanceGroupsScopedList",
    "InstanceGroupsSetNamedPortsRequest",
    "InstanceList",
    "InstanceListReferrers",
    "InstanceManagedByIgmError",
    "InstanceManagedByIgmErrorInstanceActionDetails",
    "InstanceManagedByIgmErrorManagedInstanceError",
    "InstanceMoveRequest",
    "InstanceParams",
    "InstanceProperties",
    "InstancePropertiesPatch",
    "InstanceReference",
    "InstancesAddResourcePoliciesRequest",
    "InstancesBulkInsertOperationMetadata",
    "InstanceSettings",
    "InstanceSettingsMetadata",
    "InstancesGetEffectiveFirewallsResponse",
    "InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
    "InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy",
    "InstancesRemoveResourcePoliciesRequest",
    "InstancesReportHostAsFaultyRequest",
    "InstancesReportHostAsFaultyRequestFaultReason",
    "InstancesResumeRequest",
    "InstancesScopedList",
    "InstancesSetLabelsRequest",
    "InstancesSetMachineResourcesRequest",
    "InstancesSetMachineTypeRequest",
    "InstancesSetMinCpuPlatformRequest",
    "InstancesSetNameRequest",
    "InstancesSetSecurityPolicyRequest",
    "InstancesSetServiceAccountRequest",
    "InstancesStartWithEncryptionKeyRequest",
    "InstanceTemplate",
    "InstanceTemplateAggregatedList",
    "InstanceTemplateList",
    "InstanceTemplatesScopedList",
    "InstanceWithNamedPorts",
    "InstantSnapshot",
    "InstantSnapshotAggregatedList",
    "InstantSnapshotList",
    "InstantSnapshotResourceStatus",
    "InstantSnapshotsScopedList",
    "Int64RangeMatch",
    "Interconnect",
    "InterconnectApplicationAwareInterconnect",
    "InterconnectApplicationAwareInterconnectBandwidthPercentage",
    "InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy",
    "InterconnectApplicationAwareInterconnectStrictPriorityPolicy",
    "InterconnectAttachment",
    "InterconnectAttachmentAggregatedList",
    "InterconnectAttachmentConfigurationConstraints",
    "InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange",
    "InterconnectAttachmentGroup",
    "InterconnectAttachmentGroupAttachment",
    "InterconnectAttachmentGroupConfigured",
    "InterconnectAttachmentGroupConfiguredAvailabilitySLA",
    "InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers",
    "InterconnectAttachmentGroupIntent",
    "InterconnectAttachmentGroupLogicalStructure",
    "InterconnectAttachmentGroupLogicalStructureRegion",
    "InterconnectAttachmentGroupLogicalStructureRegionMetro",
    "InterconnectAttachmentGroupLogicalStructureRegionMetroFacility",
    "InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone",
    "InterconnectAttachmentGroupsGetOperationalStatusResponse",
    "InterconnectAttachmentGroupsListResponse",
    "InterconnectAttachmentGroupsOperationalStatus",
    "InterconnectAttachmentGroupsOperationalStatusAttachmentStatus",
    "InterconnectAttachmentList",
    "InterconnectAttachmentPartnerMetadata",
    "InterconnectAttachmentPrivateInfo",
    "InterconnectAttachmentsScopedList",
    "InterconnectCircuitInfo",
    "InterconnectDiagnostics",
    "InterconnectDiagnosticsARPEntry",
    "InterconnectDiagnosticsLinkLACPStatus",
    "InterconnectDiagnosticsLinkOpticalPower",
    "InterconnectDiagnosticsLinkStatus",
    "InterconnectDiagnosticsMacsecStatus",
    "InterconnectGroup",
    "InterconnectGroupConfigured",
    "InterconnectGroupConfiguredTopologyCapability",
    "InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers",
    "InterconnectGroupIntent",
    "InterconnectGroupInterconnect",
    "InterconnectGroupPhysicalStructure",
    "InterconnectGroupPhysicalStructureMetros",
    "InterconnectGroupPhysicalStructureMetrosFacilities",
    "InterconnectGroupPhysicalStructureMetrosFacilitiesZones",
    "InterconnectGroupsCreateMembers",
    "InterconnectGroupsCreateMembersInterconnectInput",
    "InterconnectGroupsCreateMembersRequest",
    "InterconnectGroupsGetOperationalStatusResponse",
    "InterconnectGroupsListResponse",
    "InterconnectGroupsOperationalStatus",
    "InterconnectGroupsOperationalStatusInterconnectStatus",
    "InterconnectList",
    "InterconnectLocation",
    "InterconnectLocationCrossSiteInterconnectInfo",
    "InterconnectLocationList",
    "InterconnectLocationRegionInfo",
    "InterconnectMacsec",
    "InterconnectMacsecConfig",
    "InterconnectMacsecConfigPreSharedKey",
    "InterconnectMacsecPreSharedKey",
    "InterconnectOutageNotification",
    "InterconnectRemoteLocation",
    "InterconnectRemoteLocationConstraints",
    "InterconnectRemoteLocationConstraintsSubnetLengthRange",
    "InterconnectRemoteLocationList",
    "InterconnectRemoteLocationPermittedConnections",
    "InterconnectsGetDiagnosticsResponse",
    "InterconnectsGetMacsecConfigResponse",
    "InvalidateCacheRegionUrlMapRequest",
    "InvalidateCacheUrlMapRequest",
    "Items",
    "License",
    "LicenseCode",
    "LicenseCodeLicenseAlias",
    "LicenseResourceCommitment",
    "LicenseResourceRequirements",
    "LicensesListResponse",
    "ListAcceleratorTypesRequest",
    "ListAddressesRequest",
    "ListAssociationsFirewallPolicyRequest",
    "ListAssociationsOrganizationSecurityPolicyRequest",
    "ListAutoscalersRequest",
    "ListAvailableFeaturesRegionSslPoliciesRequest",
    "ListAvailableFeaturesSslPoliciesRequest",
    "ListBackendBucketsRequest",
    "ListBackendServicesRequest",
    "ListBgpRoutesRoutersRequest",
    "ListCrossSiteNetworksRequest",
    "ListDisksRequest",
    "ListDisksStoragePoolsRequest",
    "ListDiskTypesRequest",
    "ListErrorsInstanceGroupManagersRequest",
    "ListErrorsRegionInstanceGroupManagersRequest",
    "ListExternalVpnGatewaysRequest",
    "ListFirewallPoliciesRequest",
    "ListFirewallsRequest",
    "ListForwardingRulesRequest",
    "ListFutureReservationsRequest",
    "ListGlobalAddressesRequest",
    "ListGlobalForwardingRulesRequest",
    "ListGlobalNetworkEndpointGroupsRequest",
    "ListGlobalOperationsRequest",
    "ListGlobalOrganizationOperationsRequest",
    "ListGlobalPublicDelegatedPrefixesRequest",
    "ListHealthChecksRequest",
    "ListImagesRequest",
    "ListInstanceGroupManagerResizeRequestsRequest",
    "ListInstanceGroupManagersRequest",
    "ListInstanceGroupsRequest",
    "ListInstancesInstanceGroupsRequest",
    "ListInstancesRegionInstanceGroupsRequest",
    "ListInstancesRequest",
    "ListInstanceTemplatesRequest",
    "ListInstantSnapshotsRequest",
    "ListInterconnectAttachmentGroupsRequest",
    "ListInterconnectAttachmentsRequest",
    "ListInterconnectGroupsRequest",
    "ListInterconnectLocationsRequest",
    "ListInterconnectRemoteLocationsRequest",
    "ListInterconnectsRequest",
    "ListLicensesRequest",
    "ListMachineImagesRequest",
    "ListMachineTypesRequest",
    "ListManagedInstancesInstanceGroupManagersRequest",
    "ListManagedInstancesRegionInstanceGroupManagersRequest",
    "ListNetworkAttachmentsRequest",
    "ListNetworkEndpointGroupsRequest",
    "ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest",
    "ListNetworkEndpointsNetworkEndpointGroupsRequest",
    "ListNetworkEndpointsRegionNetworkEndpointGroupsRequest",
    "ListNetworkFirewallPoliciesRequest",
    "ListNetworkProfilesRequest",
    "ListNetworksRequest",
    "ListNodeGroupsRequest",
    "ListNodesNodeGroupsRequest",
    "ListNodeTemplatesRequest",
    "ListNodeTypesRequest",
    "ListOrganizationSecurityPoliciesRequest",
    "ListPacketMirroringsRequest",
    "ListPeeringRoutesNetworksRequest",
    "ListPerInstanceConfigsInstanceGroupManagersRequest",
    "ListPerInstanceConfigsRegionInstanceGroupManagersRequest",
    "ListPreconfiguredExpressionSetsOrganizationSecurityPoliciesRequest",
    "ListPreconfiguredExpressionSetsSecurityPoliciesRequest",
    "ListPreviewFeaturesRequest",
    "ListPublicAdvertisedPrefixesRequest",
    "ListPublicDelegatedPrefixesRequest",
    "ListReferrersInstancesRequest",
    "ListRegionAutoscalersRequest",
    "ListRegionBackendServicesRequest",
    "ListRegionCommitmentsRequest",
    "ListRegionDisksRequest",
    "ListRegionDiskTypesRequest",
    "ListRegionHealthCheckServicesRequest",
    "ListRegionHealthChecksRequest",
    "ListRegionInstanceGroupManagerResizeRequestsRequest",
    "ListRegionInstanceGroupManagersRequest",
    "ListRegionInstanceGroupsRequest",
    "ListRegionInstanceTemplatesRequest",
    "ListRegionInstantSnapshotsRequest",
    "ListRegionMultiMigsRequest",
    "ListRegionNetworkEndpointGroupsRequest",
    "ListRegionNetworkFirewallPoliciesRequest",
    "ListRegionNotificationEndpointsRequest",
    "ListRegionOperationsRequest",
    "ListRegionSecurityPoliciesRequest",
    "ListRegionSnapshotsRequest",
    "ListRegionsRequest",
    "ListRegionSslCertificatesRequest",
    "ListRegionSslPoliciesRequest",
    "ListRegionTargetHttpProxiesRequest",
    "ListRegionTargetHttpsProxiesRequest",
    "ListRegionTargetTcpProxiesRequest",
    "ListRegionUrlMapsRequest",
    "ListRegionZonesRequest",
    "ListReservationBlocksRequest",
    "ListReservationsRequest",
    "ListResourcePoliciesRequest",
    "ListRoutePoliciesRoutersRequest",
    "ListRoutersRequest",
    "ListRoutesRequest",
    "ListSecurityPoliciesRequest",
    "ListServiceAttachmentsRequest",
    "ListSnapshotsRequest",
    "ListSslCertificatesRequest",
    "ListSslPoliciesRequest",
    "ListStoragePoolsRequest",
    "ListStoragePoolTypesRequest",
    "ListSubnetworksRequest",
    "ListTargetGrpcProxiesRequest",
    "ListTargetHttpProxiesRequest",
    "ListTargetHttpsProxiesRequest",
    "ListTargetInstancesRequest",
    "ListTargetPoolsRequest",
    "ListTargetSslProxiesRequest",
    "ListTargetTcpProxiesRequest",
    "ListTargetVpnGatewaysRequest",
    "ListUrlMapsRequest",
    "ListUsableBackendBucketsRequest",
    "ListUsableBackendServicesRequest",
    "ListUsableRegionBackendServicesRequest",
    "ListUsableSubnetworksRequest",
    "ListVpnGatewaysRequest",
    "ListVpnTunnelsRequest",
    "ListWireGroupsRequest",
    "ListXpnHostsProjectsRequest",
    "ListZoneOperationsRequest",
    "ListZonesRequest",
    "LocalDisk",
    "LocalizedMessage",
    "LocationPolicy",
    "LocationPolicyLocation",
    "LocationPolicyLocationConstraints",
    "MachineImage",
    "MachineImageList",
    "MachineType",
    "MachineTypeAggregatedList",
    "MachineTypeList",
    "MachineTypesScopedList",
    "ManagedInstance",
    "ManagedInstanceAllInstancesConfig",
    "ManagedInstanceInstanceHealth",
    "ManagedInstanceLastAttempt",
    "ManagedInstanceLastAttemptErrors",
    "ManagedInstancePropertiesFromFlexibilityPolicy",
    "ManagedInstanceVersion",
    "Metadata",
    "MetadataFilter",
    "MetadataFilterLabelMatch",
    "MoveAddressRequest",
    "MoveDiskProjectRequest",
    "MoveFirewallPolicyRequest",
    "MoveGlobalAddressRequest",
    "MoveInstanceProjectRequest",
    "MoveOrganizationSecurityPolicyRequest",
    "MultiMig",
    "MultiMigResourcePolicies",
    "MultiMigsList",
    "NamedPort",
    "NatIpInfo",
    "NatIpInfoNatIpInfoMapping",
    "NatIpInfoResponse",
    "Network",
    "NetworkAttachment",
    "NetworkAttachmentAggregatedList",
    "NetworkAttachmentConnectedEndpoint",
    "NetworkAttachmentList",
    "NetworkAttachmentsScopedList",
    "NetworkEdgeSecurityService",
    "NetworkEdgeSecurityServiceAggregatedList",
    "NetworkEdgeSecurityServicesScopedList",
    "NetworkEndpoint",
    "NetworkEndpointGroup",
    "NetworkEndpointGroupAggregatedList",
    "NetworkEndpointGroupAppEngine",
    "NetworkEndpointGroupCloudFunction",
    "NetworkEndpointGroupCloudRun",
    "NetworkEndpointGroupLbNetworkEndpointGroup",
    "NetworkEndpointGroupList",
    "NetworkEndpointGroupPscData",
    "NetworkEndpointGroupsAttachEndpointsRequest",
    "NetworkEndpointGroupsDetachEndpointsRequest",
    "NetworkEndpointGroupServerlessDeployment",
    "NetworkEndpointGroupsListEndpointsRequest",
    "NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter",
    "NetworkEndpointGroupsListNetworkEndpoints",
    "NetworkEndpointGroupsScopedList",
    "NetworkEndpointWithHealthStatus",
    "NetworkFirewallPolicyAggregatedList",
    "NetworkInterface",
    "NetworkList",
    "NetworkParams",
    "NetworkPeering",
    "NetworkPeeringConnectionStatus",
    "NetworkPeeringConnectionStatusConsensusState",
    "NetworkPeeringConnectionStatusTrafficConfiguration",
    "NetworkPerformanceConfig",
    "NetworkProfile",
    "NetworkProfileLocation",
    "NetworkProfileNetworkFeatures",
    "NetworkProfilesListResponse",
    "NetworkRoutingConfig",
    "NetworksAddPeeringRequest",
    "NetworksGetEffectiveFirewallsResponse",
    "NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
    "NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy",
    "NetworksRemovePeeringRequest",
    "NetworksRequestRemovePeeringRequest",
    "NetworksUpdatePeeringRequest",
    "NodeGroup",
    "NodeGroupAggregatedList",
    "NodeGroupAutoscalingPolicy",
    "NodeGroupList",
    "NodeGroupMaintenanceWindow",
    "NodeGroupNode",
    "NodeGroupsAddNodesRequest",
    "NodeGroupsDeleteNodesRequest",
    "NodeGroupsListNodes",
    "NodeGroupsPerformMaintenanceRequest",
    "NodeGroupsScopedList",
    "NodeGroupsSetNodeTemplateRequest",
    "NodeGroupsSimulateMaintenanceEventRequest",
    "NodeTemplate",
    "NodeTemplateAggregatedList",
    "NodeTemplateList",
    "NodeTemplateNodeTypeFlexibility",
    "NodeTemplatesScopedList",
    "NodeType",
    "NodeTypeAggregatedList",
    "NodeTypeList",
    "NodeTypesScopedList",
    "NotificationEndpoint",
    "NotificationEndpointGrpcSettings",
    "NotificationEndpointList",
    "Operation",
    "OperationAggregatedList",
    "OperationList",
    "OperationsScopedList",
    "OrganizationSecurityPoliciesListAssociationsResponse",
    "OutlierDetection",
    "PacketIntervals",
    "PacketMirroring",
    "PacketMirroringAggregatedList",
    "PacketMirroringFilter",
    "PacketMirroringForwardingRuleInfo",
    "PacketMirroringList",
    "PacketMirroringMirroredResourceInfo",
    "PacketMirroringMirroredResourceInfoInstanceInfo",
    "PacketMirroringMirroredResourceInfoSubnetInfo",
    "PacketMirroringNetworkInfo",
    "PacketMirroringsScopedList",
    "PartnerMetadata",
    "PatchAssociationRegionNetworkFirewallPolicyRequest",
    "PatchAutoscalerRequest",
    "PatchBackendBucketRequest",
    "PatchBackendServiceRequest",
    "PatchCrossSiteNetworkRequest",
    "PatchDiskSettingRequest",
    "PatchFirewallPolicyRequest",
    "PatchFirewallRequest",
    "PatchForwardingRuleRequest",
    "PatchGlobalForwardingRuleRequest",
    "PatchGlobalPublicDelegatedPrefixeRequest",
    "PatchHealthCheckRequest",
    "PatchImageRequest",
    "PatchInstanceGroupManagerRequest",
    "PatchInstanceSettingRequest",
    "PatchInterconnectAttachmentGroupRequest",
    "PatchInterconnectAttachmentRequest",
    "PatchInterconnectGroupRequest",
    "PatchInterconnectRequest",
    "PatchNetworkAttachmentRequest",
    "PatchNetworkEdgeSecurityServiceRequest",
    "PatchNetworkFirewallPolicyRequest",
    "PatchNetworkRequest",
    "PatchNodeGroupRequest",
    "PatchOrganizationSecurityPolicyRequest",
    "PatchPacketMirroringRequest",
    "PatchPacketMirroringRuleFirewallPolicyRequest",
    "PatchPacketMirroringRuleNetworkFirewallPolicyRequest",
    "PatchPartnerMetadataInstanceRequest",
    "PatchPerInstanceConfigsInstanceGroupManagerRequest",
    "PatchPerInstanceConfigsRegionInstanceGroupManagerRequest",
    "PatchPublicAdvertisedPrefixeRequest",
    "PatchPublicDelegatedPrefixeRequest",
    "PatchRegionAutoscalerRequest",
    "PatchRegionBackendServiceRequest",
    "PatchRegionDiskSettingRequest",
    "PatchRegionHealthCheckRequest",
    "PatchRegionHealthCheckServiceRequest",
    "PatchRegionInstanceGroupManagerRequest",
    "PatchRegionNetworkFirewallPolicyRequest",
    "PatchRegionSecurityPolicyRequest",
    "PatchRegionSnapshotSettingRequest",
    "PatchRegionSslPolicyRequest",
    "PatchRegionTargetHttpsProxyRequest",
    "PatchRegionUrlMapRequest",
    "PatchResourcePolicyRequest",
    "PatchRoutePolicyRouterRequest",
    "PatchRouterRequest",
    "PatchRuleFirewallPolicyRequest",
    "PatchRuleNetworkFirewallPolicyRequest",
    "PatchRuleOrganizationSecurityPolicyRequest",
    "PatchRuleRegionNetworkFirewallPolicyRequest",
    "PatchRuleRegionSecurityPolicyRequest",
    "PatchRuleSecurityPolicyRequest",
    "PatchSecurityPolicyRequest",
    "PatchServiceAttachmentRequest",
    "PatchSnapshotSettingRequest",
    "PatchSslPolicyRequest",
    "PatchSubnetworkRequest",
    "PatchTargetGrpcProxyRequest",
    "PatchTargetHttpProxyRequest",
    "PatchTargetHttpsProxyRequest",
    "PatchUrlMapRequest",
    "PatchWireGroupRequest",
    "PathMatcher",
    "PathRule",
    "PerformMaintenanceInstanceRequest",
    "PerformMaintenanceNodeGroupRequest",
    "PerformMaintenanceReservationBlockRequest",
    "PerformMaintenanceReservationRequest",
    "PerInstanceConfig",
    "Policy",
    "PreconfiguredWafSet",
    "PreservedState",
    "PreservedStatePreservedDisk",
    "PreservedStatePreservedNetworkIp",
    "PreservedStatePreservedNetworkIpIpAddress",
    "PreviewFeature",
    "PreviewFeatureList",
    "PreviewFeatureRolloutOperation",
    "PreviewFeatureRolloutOperationRolloutInput",
    "PreviewFeatureRolloutOperationRolloutStatus",
    "PreviewFeatureRolloutOperationRolloutStatusRolloutMetadata",
    "PreviewFeatureStatus",
    "PreviewFeatureStatusReleaseStatus",
    "PreviewRouterRequest",
    "Project",
    "ProjectsDisableXpnResourceRequest",
    "ProjectsEnableXpnResourceRequest",
    "ProjectsGetXpnResources",
    "ProjectsListXpnHostsRequest",
    "ProjectsSetCloudArmorTierRequest",
    "ProjectsSetDefaultNetworkTierRequest",
    "ProjectsSetManagedProtectionTierRequest",
    "PublicAdvertisedPrefix",
    "PublicAdvertisedPrefixList",
    "PublicAdvertisedPrefixPublicDelegatedPrefix",
    "PublicDelegatedPrefix",
    "PublicDelegatedPrefixAggregatedList",
    "PublicDelegatedPrefixesScopedList",
    "PublicDelegatedPrefixList",
    "PublicDelegatedPrefixPublicDelegatedSubPrefix",
    "Quota",
    "QuotaExceededInfo",
    "QuotaStatusWarning",
    "RawDisk",
    "RecreateInstancesInstanceGroupManagerRequest",
    "RecreateInstancesRegionInstanceGroupManagerRequest",
    "Reference",
    "Region",
    "RegionAddressesMoveRequest",
    "RegionAutoscalerList",
    "RegionCommitmentsUpdateReservationsRequest",
    "RegionDisksAddResourcePoliciesRequest",
    "RegionDisksRemoveResourcePoliciesRequest",
    "RegionDisksResizeRequest",
    "RegionDisksStartAsyncReplicationRequest",
    "RegionDiskTypeList",
    "RegionInstanceGroupList",
    "RegionInstanceGroupManagerDeleteInstanceConfigReq",
    "RegionInstanceGroupManagerList",
    "RegionInstanceGroupManagerPatchInstanceConfigReq",
    "RegionInstanceGroupManagerResizeRequestsListResponse",
    "RegionInstanceGroupManagersAbandonInstancesRequest",
    "RegionInstanceGroupManagersApplyUpdatesRequest",
    "RegionInstanceGroupManagersCreateInstancesRequest",
    "RegionInstanceGroupManagersDeleteInstancesRequest",
    "RegionInstanceGroupManagersListErrorsResponse",
    "RegionInstanceGroupManagersListInstanceConfigsResp",
    "RegionInstanceGroupManagersListInstancesResponse",
    "RegionInstanceGroupManagersRecreateRequest",
    "RegionInstanceGroupManagersResizeAdvancedRequest",
    "RegionInstanceGroupManagersResumeInstancesRequest",
    "RegionInstanceGroupManagersSetAutoHealingRequest",
    "RegionInstanceGroupManagersSetTargetPoolsRequest",
    "RegionInstanceGroupManagersSetTemplateRequest",
    "RegionInstanceGroupManagersStartInstancesRequest",
    "RegionInstanceGroupManagersStopInstancesRequest",
    "RegionInstanceGroupManagersSuspendInstancesRequest",
    "RegionInstanceGroupManagerUpdateInstanceConfigReq",
    "RegionInstanceGroupsListInstances",
    "RegionInstanceGroupsListInstancesRequest",
    "RegionInstanceGroupsSetNamedPortsRequest",
    "RegionList",
    "RegionNetworkEndpointGroupsAttachEndpointsRequest",
    "RegionNetworkEndpointGroupsDetachEndpointsRequest",
    "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse",
    "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
    "RegionSetLabelsRequest",
    "RegionSetPolicyRequest",
    "RegionTargetHttpsProxiesSetSslCertificatesRequest",
    "RegionUrlMapsValidateRequest",
    "RemoveAssociationFirewallPolicyRequest",
    "RemoveAssociationNetworkFirewallPolicyRequest",
    "RemoveAssociationOrganizationSecurityPolicyRequest",
    "RemoveAssociationRegionNetworkFirewallPolicyRequest",
    "RemoveHealthCheckTargetPoolRequest",
    "RemoveInstancesInstanceGroupRequest",
    "RemoveInstanceTargetPoolRequest",
    "RemovePacketMirroringRuleFirewallPolicyRequest",
    "RemovePacketMirroringRuleNetworkFirewallPolicyRequest",
    "RemovePeeringNetworkRequest",
    "RemoveResourcePoliciesDiskRequest",
    "RemoveResourcePoliciesInstanceRequest",
    "RemoveResourcePoliciesRegionDiskRequest",
    "RemoveRuleFirewallPolicyRequest",
    "RemoveRuleNetworkFirewallPolicyRequest",
    "RemoveRuleOrganizationSecurityPolicyRequest",
    "RemoveRuleRegionNetworkFirewallPolicyRequest",
    "RemoveRuleRegionSecurityPolicyRequest",
    "RemoveRuleSecurityPolicyRequest",
    "ReportHostAsFaultyInstanceRequest",
    "RequestMirrorPolicy",
    "RequestRemovePeeringNetworkRequest",
    "Reservation",
    "ReservationAffinity",
    "ReservationAggregatedList",
    "ReservationBlock",
    "ReservationBlockPhysicalTopology",
    "ReservationBlocksGetResponse",
    "ReservationBlocksListResponse",
    "ReservationList",
    "ReservationsBlocksPerformMaintenanceRequest",
    "ReservationsPerformMaintenanceRequest",
    "ReservationsResizeRequest",
    "ReservationsScopedList",
    "ResetInstanceRequest",
    "ResizeAdvancedInstanceGroupManagerRequest",
    "ResizeAdvancedRegionInstanceGroupManagerRequest",
    "ResizeDiskRequest",
    "ResizeInstanceGroupManagerRequest",
    "ResizeRegionDiskRequest",
    "ResizeRegionInstanceGroupManagerRequest",
    "ResizeReservationRequest",
    "ResourceCommitment",
    "ResourceGroupReference",
    "ResourcePoliciesScopedList",
    "ResourcePolicy",
    "ResourcePolicyAggregatedList",
    "ResourcePolicyDailyCycle",
    "ResourcePolicyDiskConsistencyGroupPolicy",
    "ResourcePolicyGroupPlacementPolicy",
    "ResourcePolicyHourlyCycle",
    "ResourcePolicyInstanceSchedulePolicy",
    "ResourcePolicyInstanceSchedulePolicySchedule",
    "ResourcePolicyList",
    "ResourcePolicyResourceStatus",
    "ResourcePolicyResourceStatusInstanceSchedulePolicyStatus",
    "ResourcePolicySnapshotSchedulePolicy",
    "ResourcePolicySnapshotSchedulePolicyRetentionPolicy",
    "ResourcePolicySnapshotSchedulePolicySchedule",
    "ResourcePolicySnapshotSchedulePolicySnapshotProperties",
    "ResourcePolicyWeeklyCycle",
    "ResourcePolicyWeeklyCycleDayOfWeek",
    "ResourcePolicyWorkloadPolicy",
    "ResourceStatus",
    "ResourceStatusPhysicalHostTopology",
    "ResourceStatusScheduling",
    "ResourceStatusShutdownDetails",
    "ResumeInstanceRequest",
    "ResumeInstancesInstanceGroupManagerRequest",
    "ResumeInstancesRegionInstanceGroupManagerRequest",
    "RolloutPolicy",
    "Route",
    "RouteAsPath",
    "RouteList",
    "RouteParams",
    "RoutePolicy",
    "RoutePolicyPolicyTerm",
    "Router",
    "RouterAdvertisedIpRange",
    "RouterAggregatedList",
    "RouterBgp",
    "RouterBgpPeer",
    "RouterBgpPeerBfd",
    "RouterBgpPeerCustomLearnedIpRange",
    "RouterInterface",
    "RouterList",
    "RouterMd5AuthenticationKey",
    "RouterNat",
    "RouterNatLogConfig",
    "RouterNatRule",
    "RouterNatRuleAction",
    "RouterNatSubnetworkToNat",
    "RouterNatSubnetworkToNat64",
    "RoutersGetRoutePolicyResponse",
    "RoutersListBgpRoutes",
    "RoutersListRoutePolicies",
    "RoutersPreviewResponse",
    "RoutersScopedList",
    "RouterStatus",
    "RouterStatusBgpPeerStatus",
    "RouterStatusNatStatus",
    "RouterStatusNatStatusNatRuleStatus",
    "RouterStatusResponse",
    "SavedAttachedDisk",
    "SavedDisk",
    "ScalingScheduleStatus",
    "Scheduling",
    "SchedulingGracefulShutdown",
    "SchedulingNodeAffinity",
    "SchedulingOnInstanceStopAction",
    "Screenshot",
    "SecurityPoliciesAggregatedList",
    "SecurityPoliciesListPreconfiguredExpressionSetsResponse",
    "SecurityPoliciesScopedList",
    "SecurityPoliciesWafConfig",
    "SecurityPolicy",
    "SecurityPolicyAdaptiveProtectionConfig",
    "SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig",
    "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig",
    "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig",
    "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig",
    "SecurityPolicyAdvancedOptionsConfig",
    "SecurityPolicyAdvancedOptionsConfigJsonCustomConfig",
    "SecurityPolicyAssociation",
    "SecurityPolicyDdosProtectionConfig",
    "SecurityPolicyList",
    "SecurityPolicyRecaptchaOptionsConfig",
    "SecurityPolicyReference",
    "SecurityPolicyRule",
    "SecurityPolicyRuleHttpHeaderAction",
    "SecurityPolicyRuleHttpHeaderActionHttpHeaderOption",
    "SecurityPolicyRuleMatcher",
    "SecurityPolicyRuleMatcherConfig",
    "SecurityPolicyRuleMatcherConfigLayer4Config",
    "SecurityPolicyRuleMatcherExprOptions",
    "SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions",
    "SecurityPolicyRuleNetworkMatcher",
    "SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch",
    "SecurityPolicyRulePreconfiguredWafConfig",
    "SecurityPolicyRulePreconfiguredWafConfigExclusion",
    "SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams",
    "SecurityPolicyRuleRateLimitOptions",
    "SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig",
    "SecurityPolicyRuleRateLimitOptionsThreshold",
    "SecurityPolicyRuleRedirectOptions",
    "SecurityPolicyUserDefinedField",
    "SecuritySettings",
    "SendDiagnosticInterruptInstanceRequest",
    "SendDiagnosticInterruptInstanceResponse",
    "SerialPortOutput",
    "ServerBinding",
    "ServiceAccount",
    "ServiceAttachment",
    "ServiceAttachmentAggregatedList",
    "ServiceAttachmentConnectedEndpoint",
    "ServiceAttachmentConsumerProjectLimit",
    "ServiceAttachmentList",
    "ServiceAttachmentsScopedList",
    "ServiceAttachmentTunnelingConfig",
    "SetAutoHealingPoliciesInstanceGroupManagerRequest",
    "SetAutoHealingPoliciesRegionInstanceGroupManagerRequest",
    "SetBackendServiceTargetSslProxyRequest",
    "SetBackendServiceTargetTcpProxyRequest",
    "SetBackupTargetPoolRequest",
    "SetCertificateMapTargetHttpsProxyRequest",
    "SetCertificateMapTargetSslProxyRequest",
    "SetCloudArmorTierProjectRequest",
    "SetCommonInstanceMetadataOperationMetadata",
    "SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo",
    "SetCommonInstanceMetadataProjectRequest",
    "SetDefaultNetworkTierProjectRequest",
    "SetDeletionProtectionInstanceRequest",
    "SetDiskAutoDeleteInstanceRequest",
    "SetEdgeSecurityPolicyBackendBucketRequest",
    "SetEdgeSecurityPolicyBackendServiceRequest",
    "SetIamPolicyBackendBucketRequest",
    "SetIamPolicyBackendServiceRequest",
    "SetIamPolicyDiskRequest",
    "SetIamPolicyFirewallPolicyRequest",
    "SetIamPolicyImageRequest",
    "SetIamPolicyInstanceRequest",
    "SetIamPolicyInstanceTemplateRequest",
    "SetIamPolicyInstantSnapshotRequest",
    "SetIamPolicyInterconnectAttachmentGroupRequest",
    "SetIamPolicyInterconnectGroupRequest",
    "SetIamPolicyLicenseRequest",
    "SetIamPolicyMachineImageRequest",
    "SetIamPolicyNetworkAttachmentRequest",
    "SetIamPolicyNetworkFirewallPolicyRequest",
    "SetIamPolicyNodeGroupRequest",
    "SetIamPolicyNodeTemplateRequest",
    "SetIamPolicyRegionBackendServiceRequest",
    "SetIamPolicyRegionDiskRequest",
    "SetIamPolicyRegionInstantSnapshotRequest",
    "SetIamPolicyRegionNetworkFirewallPolicyRequest",
    "SetIamPolicyRegionSnapshotRequest",
    "SetIamPolicyReservationRequest",
    "SetIamPolicyResourcePolicyRequest",
    "SetIamPolicyServiceAttachmentRequest",
    "SetIamPolicySnapshotRequest",
    "SetIamPolicyStoragePoolRequest",
    "SetIamPolicySubnetworkRequest",
    "SetInstanceTemplateInstanceGroupManagerRequest",
    "SetInstanceTemplateRegionInstanceGroupManagerRequest",
    "SetLabelsAddressRequest",
    "SetLabelsDiskRequest",
    "SetLabelsExternalVpnGatewayRequest",
    "SetLabelsForwardingRuleRequest",
    "SetLabelsGlobalAddressRequest",
    "SetLabelsGlobalForwardingRuleRequest",
    "SetLabelsImageRequest",
    "SetLabelsInstanceRequest",
    "SetLabelsInstantSnapshotRequest",
    "SetLabelsInterconnectAttachmentRequest",
    "SetLabelsInterconnectRequest",
    "SetLabelsMachineImageRequest",
    "SetLabelsRegionDiskRequest",
    "SetLabelsRegionInstantSnapshotRequest",
    "SetLabelsRegionSecurityPolicyRequest",
    "SetLabelsRegionSnapshotRequest",
    "SetLabelsSecurityPolicyRequest",
    "SetLabelsSnapshotRequest",
    "SetLabelsTargetVpnGatewayRequest",
    "SetLabelsVpnGatewayRequest",
    "SetLabelsVpnTunnelRequest",
    "SetMachineResourcesInstanceRequest",
    "SetMachineTypeInstanceRequest",
    "SetManagedProtectionTierProjectRequest",
    "SetMetadataInstanceRequest",
    "SetMinCpuPlatformInstanceRequest",
    "SetNamedPortsInstanceGroupRequest",
    "SetNamedPortsRegionInstanceGroupRequest",
    "SetNameInstanceRequest",
    "SetNodeTemplateNodeGroupRequest",
    "SetPrivateIpGoogleAccessSubnetworkRequest",
    "SetProxyHeaderTargetSslProxyRequest",
    "SetProxyHeaderTargetTcpProxyRequest",
    "SetQuicOverrideTargetHttpsProxyRequest",
    "SetSchedulingInstanceRequest",
    "SetSecurityPolicyBackendServiceRequest",
    "SetSecurityPolicyInstanceRequest",
    "SetSecurityPolicyRegionBackendServiceRequest",
    "SetSecurityPolicyTargetInstanceRequest",
    "SetSecurityPolicyTargetPoolRequest",
    "SetServiceAccountInstanceRequest",
    "SetShieldedInstanceIntegrityPolicyInstanceRequest",
    "SetShieldedVmIntegrityPolicyInstanceRequest",
    "SetSslCertificatesRegionTargetHttpsProxyRequest",
    "SetSslCertificatesTargetHttpsProxyRequest",
    "SetSslCertificatesTargetSslProxyRequest",
    "SetSslPolicyTargetHttpsProxyRequest",
    "SetSslPolicyTargetSslProxyRequest",
    "SetTagsInstanceRequest",
    "SetTargetForwardingRuleRequest",
    "SetTargetGlobalForwardingRuleRequest",
    "SetTargetPoolsInstanceGroupManagerRequest",
    "SetTargetPoolsRegionInstanceGroupManagerRequest",
    "SetUrlMapRegionTargetHttpProxyRequest",
    "SetUrlMapRegionTargetHttpsProxyRequest",
    "SetUrlMapTargetHttpProxyRequest",
    "SetUrlMapTargetHttpsProxyRequest",
    "SetUsageExportBucketProjectRequest",
    "ShareSettings",
    "ShareSettingsProjectConfig",
    "ShieldedInstanceConfig",
    "ShieldedInstanceIdentity",
    "ShieldedInstanceIdentityEntry",
    "ShieldedInstanceIntegrityPolicy",
    "ShieldedVmConfig",
    "ShieldedVmIdentity",
    "ShieldedVmIdentityEntry",
    "ShieldedVmIntegrityPolicy",
    "SignedUrlKey",
    "SimulateMaintenanceEventInstanceRequest",
    "SimulateMaintenanceEventNodeGroupRequest",
    "Snapshot",
    "SnapshotAggregatedList",
    "SnapshotList",
    "SnapshotSettings",
    "SnapshotSettingsAccessLocation",
    "SnapshotSettingsAccessLocationAccessLocationPreference",
    "SnapshotSettingsStorageLocationSettings",
    "SnapshotSettingsStorageLocationSettingsStorageLocationPreference",
    "SnapshotsScopedList",
    "SourceDiskEncryptionKey",
    "SourceInstanceParams",
    "SourceInstanceProperties",
    "SslCertificate",
    "SslCertificateAggregatedList",
    "SslCertificateList",
    "SslCertificateManagedSslCertificate",
    "SslCertificateSelfManagedSslCertificate",
    "SslCertificatesScopedList",
    "SSLHealthCheck",
    "SslPoliciesAggregatedList",
    "SslPoliciesList",
    "SslPoliciesListAvailableFeaturesResponse",
    "SslPoliciesScopedList",
    "SslPolicy",
    "SslPolicyReference",
    "StartAsyncReplicationDiskRequest",
    "StartAsyncReplicationRegionDiskRequest",
    "StartInstanceRequest",
    "StartInstancesInstanceGroupManagerRequest",
    "StartInstancesRegionInstanceGroupManagerRequest",
    "StartWithEncryptionKeyInstanceRequest",
    "StatefulPolicy",
    "StatefulPolicyPreservedState",
    "StatefulPolicyPreservedStateDiskDevice",
    "StatefulPolicyPreservedStateNetworkIp",
    "Status",
    "StopAsyncReplicationDiskRequest",
    "StopAsyncReplicationRegionDiskRequest",
    "StopGroupAsyncReplicationDiskRequest",
    "StopGroupAsyncReplicationRegionDiskRequest",
    "StopInstanceRequest",
    "StopInstancesInstanceGroupManagerRequest",
    "StopInstancesRegionInstanceGroupManagerRequest",
    "StoragePool",
    "StoragePoolAggregatedList",
    "StoragePoolDisk",
    "StoragePoolList",
    "StoragePoolListDisks",
    "StoragePoolResourceStatus",
    "StoragePoolsScopedList",
    "StoragePoolType",
    "StoragePoolTypeAggregatedList",
    "StoragePoolTypeList",
    "StoragePoolTypesScopedList",
    "StructuredEntries",
    "Subnetwork",
    "SubnetworkAggregatedList",
    "SubnetworkList",
    "SubnetworkLogConfig",
    "SubnetworkParams",
    "SubnetworkSecondaryRange",
    "SubnetworksExpandIpCidrRangeRequest",
    "SubnetworksScopedList",
    "SubnetworksScopedWarning",
    "SubnetworksSetPrivateIpGoogleAccessRequest",
    "Subsetting",
    "SuspendInstanceRequest",
    "SuspendInstancesInstanceGroupManagerRequest",
    "SuspendInstancesRegionInstanceGroupManagerRequest",
    "SwitchToCustomModeNetworkRequest",
    "Tags",
    "TargetGrpcProxy",
    "TargetGrpcProxyList",
    "TargetHttpProxiesScopedList",
    "TargetHttpProxy",
    "TargetHttpProxyAggregatedList",
    "TargetHttpProxyList",
    "TargetHttpsProxiesScopedList",
    "TargetHttpsProxiesSetCertificateMapRequest",
    "TargetHttpsProxiesSetQuicOverrideRequest",
    "TargetHttpsProxiesSetSslCertificatesRequest",
    "TargetHttpsProxy",
    "TargetHttpsProxyAggregatedList",
    "TargetHttpsProxyList",
    "TargetInstance",
    "TargetInstanceAggregatedList",
    "TargetInstanceList",
    "TargetInstancesScopedList",
    "TargetPool",
    "TargetPoolAggregatedList",
    "TargetPoolInstanceHealth",
    "TargetPoolList",
    "TargetPoolsAddHealthCheckRequest",
    "TargetPoolsAddInstanceRequest",
    "TargetPoolsRemoveHealthCheckRequest",
    "TargetPoolsRemoveInstanceRequest",
    "TargetPoolsScopedList",
    "TargetReference",
    "TargetSslProxiesSetBackendServiceRequest",
    "TargetSslProxiesSetCertificateMapRequest",
    "TargetSslProxiesSetProxyHeaderRequest",
    "TargetSslProxiesSetSslCertificatesRequest",
    "TargetSslProxy",
    "TargetSslProxyList",
    "TargetTcpProxiesScopedList",
    "TargetTcpProxiesSetBackendServiceRequest",
    "TargetTcpProxiesSetProxyHeaderRequest",
    "TargetTcpProxy",
    "TargetTcpProxyAggregatedList",
    "TargetTcpProxyList",
    "TargetVpnGateway",
    "TargetVpnGatewayAggregatedList",
    "TargetVpnGatewayList",
    "TargetVpnGatewaysScopedList",
    "TCPHealthCheck",
    "TestFailure",
    "TestIamPermissionsAddressRequest",
    "TestIamPermissionsAutoscalerRequest",
    "TestIamPermissionsBackendBucketRequest",
    "TestIamPermissionsBackendServiceRequest",
    "TestIamPermissionsDiskRequest",
    "TestIamPermissionsExternalVpnGatewayRequest",
    "TestIamPermissionsFirewallPolicyRequest",
    "TestIamPermissionsFirewallRequest",
    "TestIamPermissionsForwardingRuleRequest",
    "TestIamPermissionsGlobalAddressRequest",
    "TestIamPermissionsGlobalForwardingRuleRequest",
    "TestIamPermissionsHealthCheckRequest",
    "TestIamPermissionsImageRequest",
    "TestIamPermissionsInstanceGroupManagerRequest",
    "TestIamPermissionsInstanceGroupRequest",
    "TestIamPermissionsInstanceRequest",
    "TestIamPermissionsInstanceTemplateRequest",
    "TestIamPermissionsInstantSnapshotRequest",
    "TestIamPermissionsInterconnectAttachmentGroupRequest",
    "TestIamPermissionsInterconnectAttachmentRequest",
    "TestIamPermissionsInterconnectGroupRequest",
    "TestIamPermissionsInterconnectRequest",
    "TestIamPermissionsLicenseCodeRequest",
    "TestIamPermissionsLicenseRequest",
    "TestIamPermissionsMachineImageRequest",
    "TestIamPermissionsNetworkAttachmentRequest",
    "TestIamPermissionsNetworkEndpointGroupRequest",
    "TestIamPermissionsNetworkFirewallPolicyRequest",
    "TestIamPermissionsNetworkRequest",
    "TestIamPermissionsNodeGroupRequest",
    "TestIamPermissionsNodeTemplateRequest",
    "TestIamPermissionsPacketMirroringRequest",
    "TestIamPermissionsRegionAutoscalerRequest",
    "TestIamPermissionsRegionBackendServiceRequest",
    "TestIamPermissionsRegionCommitmentRequest",
    "TestIamPermissionsRegionDiskRequest",
    "TestIamPermissionsRegionHealthCheckRequest",
    "TestIamPermissionsRegionHealthCheckServiceRequest",
    "TestIamPermissionsRegionInstanceGroupManagerRequest",
    "TestIamPermissionsRegionInstanceGroupRequest",
    "TestIamPermissionsRegionInstantSnapshotRequest",
    "TestIamPermissionsRegionNetworkFirewallPolicyRequest",
    "TestIamPermissionsRegionNotificationEndpointRequest",
    "TestIamPermissionsRegionSnapshotRequest",
    "TestIamPermissionsRegionSslCertificateRequest",
    "TestIamPermissionsRegionSslPolicyRequest",
    "TestIamPermissionsRegionTargetHttpProxyRequest",
    "TestIamPermissionsRegionTargetHttpsProxyRequest",
    "TestIamPermissionsRegionTargetTcpProxyRequest",
    "TestIamPermissionsRegionUrlMapRequest",
    "TestIamPermissionsReservationRequest",
    "TestIamPermissionsResourcePolicyRequest",
    "TestIamPermissionsRouteRequest",
    "TestIamPermissionsRouterRequest",
    "TestIamPermissionsSecurityPolicyRequest",
    "TestIamPermissionsServiceAttachmentRequest",
    "TestIamPermissionsSnapshotRequest",
    "TestIamPermissionsSslCertificateRequest",
    "TestIamPermissionsSslPolicyRequest",
    "TestIamPermissionsStoragePoolRequest",
    "TestIamPermissionsSubnetworkRequest",
    "TestIamPermissionsTargetGrpcProxyRequest",
    "TestIamPermissionsTargetHttpProxyRequest",
    "TestIamPermissionsTargetHttpsProxyRequest",
    "TestIamPermissionsTargetInstanceRequest",
    "TestIamPermissionsTargetPoolRequest",
    "TestIamPermissionsTargetSslProxyRequest",
    "TestIamPermissionsTargetTcpProxyRequest",
    "TestIamPermissionsTargetVpnGatewayRequest",
    "TestIamPermissionsUrlMapRequest",
    "TestIamPermissionsVpnGatewayRequest",
    "TestIamPermissionsVpnTunnelRequest",
    "TestPermissionsRequest",
    "TestPermissionsResponse",
    "Uint128",
    "UpcomingMaintenance",
    "UpdateAccessConfigInstanceRequest",
    "UpdateAutoscalerRequest",
    "UpdateBackendBucketRequest",
    "UpdateBackendServiceRequest",
    "UpdateDiskRequest",
    "UpdateDisplayDeviceInstanceRequest",
    "UpdateFirewallRequest",
    "UpdateFutureReservationRequest",
    "UpdateHealthCheckRequest",
    "UpdateInstanceGroupManagerRequest",
    "UpdateInstanceRequest",
    "UpdateLicenseRequest",
    "UpdateNetworkInterfaceInstanceRequest",
    "UpdatePeeringNetworkRequest",
    "UpdatePerInstanceConfigsInstanceGroupManagerRequest",
    "UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest",
    "UpdatePreviewFeatureRequest",
    "UpdateRegionAutoscalerRequest",
    "UpdateRegionBackendServiceRequest",
    "UpdateRegionCommitmentRequest",
    "UpdateRegionDiskRequest",
    "UpdateRegionHealthCheckRequest",
    "UpdateRegionInstanceGroupManagerRequest",
    "UpdateRegionUrlMapRequest",
    "UpdateReservationRequest",
    "UpdateReservationsRegionCommitmentRequest",
    "UpdateRoutePolicyRouterRequest",
    "UpdateRouterRequest",
    "UpdateShieldedInstanceConfigInstanceRequest",
    "UpdateShieldedVmConfigInstanceRequest",
    "UpdateStoragePoolRequest",
    "UpdateUrlMapRequest",
    "UrlMap",
    "UrlMapList",
    "UrlMapReference",
    "UrlMapsAggregatedList",
    "UrlMapsScopedList",
    "UrlMapsValidateRequest",
    "UrlMapsValidateResponse",
    "UrlMapTest",
    "UrlMapTestHeader",
    "UrlMapValidationResult",
    "UrlRewrite",
    "UsableSubnetwork",
    "UsableSubnetworksAggregatedList",
    "UsableSubnetworkSecondaryRange",
    "UsageExportLocation",
    "ValidateRegionUrlMapRequest",
    "ValidateUrlMapRequest",
    "VmEndpointNatMappings",
    "VmEndpointNatMappingsInterfaceNatMappings",
    "VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings",
    "VmEndpointNatMappingsList",
    "VpnGateway",
    "VpnGatewayAggregatedList",
    "VpnGatewayList",
    "VpnGatewaysGetStatusResponse",
    "VpnGatewaysScopedList",
    "VpnGatewayStatus",
    "VpnGatewayStatusHighAvailabilityRequirementState",
    "VpnGatewayStatusTunnel",
    "VpnGatewayStatusVpnConnection",
    "VpnGatewayVpnGatewayInterface",
    "VpnTunnel",
    "VpnTunnelAggregatedList",
    "VpnTunnelList",
    "VpnTunnelsScopedList",
    "WafExpressionSet",
    "WafExpressionSetExpression",
    "WaitGlobalOperationRequest",
    "WaitRegionOperationRequest",
    "WaitZoneOperationRequest",
    "Warning",
    "Warnings",
    "WeightedBackendService",
    "Wire",
    "WireEndpoint",
    "WireGroup",
    "WireGroupEndpoint",
    "WireGroupEndpointInterconnect",
    "WireGroupList",
    "WireGroupProperties",
    "WireGroupTopology",
    "WireGroupTopologyEndpoint",
    "WireProperties",
    "WithdrawPublicAdvertisedPrefixeRequest",
    "WithdrawPublicDelegatedPrefixeRequest",
    "XpnHostList",
    "XpnResourceId",
    "Zone",
    "ZoneList",
    "ZoneSetLabelsRequest",
    "ZoneSetPolicyRequest",
)
